;;; cz-print.el --- Print iso-8859-2 text from the buffer as PostScript

;; Copyright (C) 1998 Free Software Foundation, Inc.

;; Author:     Jan Prikryl <prikryl@acm.org>
;; Maintainer: Jan Prikryl <prikryl@acm.org>
;; Keywords:   print, PostScript, Czech, iso-8859-2
;; Time-stamp: <07-Aug-98 11:06:44 prikryl>
;; Version:    3.06.3

(defconst cz-print-version "3.06.3"
  "cz-print.el, v 3.06.3 <98/08/07 prikryl>

Please send all bug fixes and enhancements to Jan Prikryl <prikryl@acm.org>.")

;; This file is part of GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;; =================================================================
;;
;; Contributors: 
;;
;; Julius Chroboczek <jec@dcs.ed.ac.uk> designed the original ogonkify
;; package. The postscript code for generating composite characters as
;; well as the composite characters for Courier, Helvetica and Times
;; font families came from him. For further information about ogonkify,
;; have a look at
;;
;;      http://www.dcs.ed.ac.uk/home/jec/ogonkify/ogonkify.html
;;
;; Petr Olsak <olsak@math.feld.cvut.cz> is the author of 'a2ac'
;; utility that has been used to generate the AFM files containing the
;; new composite characters for the other font families used by Emacs.
;;
;; Milan Zamazal <pdm@fi.muni.cz> had originally the idea of tweaking
;; the ps-print.el to be able to print Czech characters. He also
;; suggested the system of encoding identification via
;; 'find-charset-string.
;;
;; Jim Thompson (was <thompson@wg2.waii.com>), Jacques Duthen
;; <duthen@cegelec-red.fr> and Vinicius Jose Latorre
;; <vinicius@cpqd.com.br> are authors of the original ps-print.el,
;; from which the function 'ps-begin-file' and the prologues have been
;; stolen.

;; =================================================================
;;
;; Installation:
;;
;; 1) Check whether the version of `ps-print.el' and `cz-print.el' are
;;    the same. Obviously, different versions of both libraries may
;;    not work together, giving either error messages or even simply
;;    not providing desired output.
;;
;; 2) Put `cz-print.el' somewhere into your load-path
;;
;; 3) Add the following two lines into your .emacs file:
;;
;;    (require 'cz-print)
;;
;;    (`cz-print' redefines functions originally used by ps-print,
;;    hence any further loading of `ps-print' after `cz-print' has
;;    been loaded will discard the changes and printing will not work
;;    as expected).
;;
;; 4) Print your iso-8859-2 files with accents on an arbitrary PS
;;    printer.

;; =================================================================
;;
;; Caveats:
;;
;; * after `ps-print' has been loaded manually from the emacs session,
;;   changes made by `cz-print' are not valid anymore and emacs prints
;;   again in iso-8859-1 encoding only
;; * calling ps-spool-buffer for iso-8859-1 and iso-8859-2 texts won't
;;   yield the supposed output: the whole spool will either use the
;;   iso-8859-2 charset or the iso-8859-1 charset. It depends on which
;;   buffer has been spooled first  

(require 'ps-print)

(if (not (string-match cz-print-version ps-print-version))
    (message
     "Warning: cz-print v. %s may be not compatible with ps-print v. %s"
     cz-print-version ps-print-version))
    
(defvar ps-print-prologue-iso-8859-1
  "% ISOLatin1Encoding stolen from ps_init.ps in GhostScript 2.6.1.4:
/ISOLatin1Encoding where { pop } {
% -- The ISO Latin-1 encoding vector isn't known, so define it.
% -- The first half is the same as the standard encoding,
% -- except for minus instead of hyphen at code 055.
/ISOLatin1Encoding
StandardEncoding 0 45 getinterval aload pop
    /minus
StandardEncoding 46 82 getinterval aload pop
%*** NOTE: the following are missing in the Adobe documentation,
%*** but appear in the displayed table:
%*** macron at 0225, dieresis at 0230, cedilla at 0233, space at 0240.
% 0200 (128)
    /.notdef /.notdef /.notdef /.notdef /.notdef /.notdef /.notdef /.notdef
    /.notdef /.notdef /.notdef /.notdef /.notdef /.notdef /.notdef /.notdef
    /dotlessi /grave /acute /circumflex /tilde /macron /breve /dotaccent
    /dieresis /.notdef /ring /cedilla /.notdef /hungarumlaut /ogonek /caron
% 0240 (160)
    /space /exclamdown /cent /sterling
	/currency /yen /brokenbar /section
    /dieresis /copyright /ordfeminine /guillemotleft
	/logicalnot /hyphen /registered /macron
    /degree /plusminus /twosuperior /threesuperior
	/acute /mu /paragraph /periodcentered
    /cedilla /onesuperior /ordmasculine /guillemotright
	/onequarter /onehalf /threequarters /questiondown
% 0300 (192)
    /Agrave /Aacute /Acircumflex /Atilde
	/Adieresis /Aring /AE /Ccedilla
    /Egrave /Eacute /Ecircumflex /Edieresis
	/Igrave /Iacute /Icircumflex /Idieresis
    /Eth /Ntilde /Ograve /Oacute
	/Ocircumflex /Otilde /Odieresis /multiply
    /Oslash /Ugrave /Uacute /Ucircumflex
	/Udieresis /Yacute /Thorn /germandbls
% 0340 (224)
    /agrave /aacute /acircumflex /atilde
	/adieresis /aring /ae /ccedilla
    /egrave /eacute /ecircumflex /edieresis
	/igrave /iacute /icircumflex /idieresis
    /eth /ntilde /ograve /oacute
	/ocircumflex /otilde /odieresis /divide
    /oslash /ugrave /uacute /ucircumflex
	/udieresis /yacute /thorn /ydieresis
256 packedarray def
} ifelse

/reencodeFontISO { %def
  dup
  length 12 add dict	% Make a new font (a new dict the same size
			% as the old one) with room for our new symbols.

  begin			% Make the new font the current dictionary.


    { 1 index /FID ne
      { def } { pop pop } ifelse
    } forall		% Copy each of the symbols from the old dictionary
			% to the new one except for the font ID.

    /Encoding ISOLatin1Encoding def	% Override the encoding with
					% the ISOLatin1 encoding.

    % Use the font's bounding box to determine the ascent, descent,
    % and overall height; don't forget that these values have to be
    % transformed using the font's matrix.

%          ^    (x2 y2)
%          |       |
%          |       v
%          |  +----+ - -
%          |  |    |   ^
%          |  |    |   | Ascent (usually > 0)
%          |  |    |   |
% (0 0) -> +--+----+-------->
%             |    |   |
%             |    |   v Descent (usually < 0)
% (x1 y1) --> +----+ - -

    FontBBox				% -- x1 y1 x2 y2
    FontMatrix transform /Ascent  exch def pop
    FontMatrix transform /Descent exch def pop
    /FontHeight Ascent Descent sub def	% use `sub' because descent < 0

    % Define these in case they're not in the FontInfo
    % (also, here they're easier to get to).
    /UnderlinePosition  Descent 0.70 mul def
    /OverlinePosition   Descent UnderlinePosition sub Ascent add def
    /StrikeoutPosition  Ascent 0.30 mul def
    /LineThickness      0  50 FontMatrix transform exch pop def
    /Xshadow            0  80 FontMatrix transform exch pop def
    /Yshadow            0 -90 FontMatrix transform exch pop def
    /SpaceBackground    Descent neg UnderlinePosition add def
    /XBox               Descent neg def
    /YBox               LineThickness 0.7 mul def

    currentdict		% Leave the new font on the stack
    end			% Stop using the font as the current dictionary.
    definefont		% Put the font into the font dictionary
    pop			% Discard the returned font.
} bind def
")

;; According to the wish of Juliusz Chroboczek, the part containing
;; the original code from composite.ps is stored in a separate
;; variable. This variable _must_ contain the 1:1 copy of composite.ps
;; from the original ogonkify package.

(defvar ps-print-prologue-iso-8859-2-composite
  "%!
% Add composite (i.e. accented) characters to any font
% By J. Chroboczek <jec@dcs.ed.ac.uk>
% Copyright (c) 1996, 1997 by J. Chroboczek.
% -- code follows this line --
%%BeginResource: procset composite 0.7 2
/makeCompositeDict 20 dict def
makeCompositeDict begin
/nameUnique {                           % name nameUnique namexxxxxx
  dup length exch 1 index string cvs    % length (name)
  1 index 12 add string dup             % length (name) (...) (...)
  3 2 roll 0 exch putinterval           % length (name...)
  dup 3 2 roll
  rand 12 string cvs
  putinterval
} bind def

/doMakeComposite
{
  /compositeChars exch def
  /targetEncoding exch def
  /baseEncoding exch def
  /newfontname exch def
  /oldfontname exch def
  /oldfont oldfontname findfont def
  /newfont 20 dict def
  /oldFontMatrix oldfont /FontMatrix get def
  /oldFontBBox oldfont /FontBBox get cvlit def
  /oldfontcopy oldfont length dict def

  newfont begin
    /FontType 3 def
    /PaintType 0 def      % not used
    /FontMatrix [0.001 0 0 0.001 0 0] def
    /FontBBox
    [
      oldFontBBox 0 get oldFontBBox 1 get
      oldFontMatrix transform
      [1000 0 0 1000 0 0] transform
      oldFontBBox 2 get oldFontBBox 3 get
      oldFontMatrix transform
      [1000 0 0 1000 0 0] transform
    ] cvx def

    /StrokeWidth 0 def                  % not used

    /Encoding targetEncoding def

    /Decoding 256 dict def              % invert base encoding vector
    Decoding begin
      0 1 255
      { dup baseEncoding exch get exch def } bind for
    end

    newfont /compositeChars compositeChars put

    /FontName newfontname def

% make a copy of the original font, reencoding it
    oldfont
    oldfontcopy begin
      {1 index /FID ne
        {def}
        {pop pop} ifelse
      } bind forall
    end
    oldfontcopy /Encoding baseEncoding put
    oldfontname nameUnique oldfontcopy definefont
    1000 scalefont /OriginalFont exch def

    /BuildChar                          % newfont n BuildChar -
    {
      exch begin                        % n
        /OriginalFont load setfont
        /Encoding load exch get         % glyphName
        /compositeChars load dup
        2 index known                   % glyphName compositeChars known-p
        { 1 index get                   % glyphName [ 65 x y 129 ]
          dup 0 get ( ) dup             % glyphName [...] 65 ( ) ( )
          0 3 index put                 % glyphName [...] 65 (A)
          dup stringwidth setcharwidth
          0 0 moveto
          show pop                      % glyphName [...]
          dup 1 get 1 index 2 get       % glyphName [...] x y
          moveto                        % glyphName [...]
          3 get ( ) dup 3 2 roll        % glyphName ( ) ( ) 129
          0 exch put                    % glyphName (')
          show                          % glyphName
        }
        { pop
          /Decoding load                % glyphName Decoding
          dup 2 index known             % glyphName Decoding known-p
          { exch get }
          { pop pop 0 } ifelse          % n'
          ( ) dup 0 3 index put dup     % n' (A) (A)
          stringwidth setcharwidth
          0 0 moveto
          show                          % n'
        } ifelse
        pop
      end
    } bind def
  end                                   % newfont
  newfontname newfont definefont pop
} def                                   % doMakeComposite
end                                     % makeCompositeDict

% oldfontname newfontname baseEncoding targetEncoding compositeChars --
/makeComposite
{
  makeCompositeDict begin doMakeComposite end
} bind def
%%EndResource
")

(defvar ps-print-prologue-iso-8859-2-fonts
  "%
% ----------------------------------------- Proprietary OgonkiEncoding vector
%
%%BeginResource: encoding OgonkiEncoding
/OgonkiEncoding [
  /.notdef /exclamdown /cent /sterling
  /fraction /yen /florin /quotesingle
  /quotedblleft /guillemotleft /guilsinglleft
  /guilsinglright /fi /fl /endash /dagger
  /daggerdbl /periodcentered /paragraph /bullet
  /quotesinglbase /quotedblbase /quotedblright /guillemotright
  /ellipsis /perthousand /questiondown /grave
  /circumflex /tilde /macron /ring
  /space /exclam /quotedbl /numbersign
  /dollar /percent /ampersand /quoteright
  /parenleft /parenright /asterisk /plus
  /comma /minus /period /slash
  /zero /one /two /three
  /four /five /six /seven
  /eight /nine /colon /semicolon
  /less /equal /greater /question
% 0100
  /at /A /B /C 
  /D /E /F /G
  /H /I /J /K
  /L /M /N /O
  /P /Q /R /S
  /T /U /V /W
  /X /Y /Z /bracketleft
  /backslash /bracketright /asciicircum /underscore
  /quoteleft /a /b /c
  /d /e /f /g
  /h /i /j /k
  /l /m /n /o
  /p /q /r /s
  /t /u /v /w
  /x /y /z /braceleft
  /bar /braceright /asciitilde /.notdef
% 0200
  /.notdef /emdash /AE /ordfeminine
  /Oslash /OE /ordmasculine /ae
  /dotlessi /oslash /oe /threesuperior
  /thorn /twosuperior /threequarters /Eth
  /trademark /registered /onequarter /Thorn
  /logicalnot /plusminus /minus /onesuperior
  /copyright /mu /eth /brokenbar
  /onehalf /dotlessj /.notdef /.notdef
  /space /Aogonek /breve /Lslash
  /currency /Lcaron /Sacute /section
  /dieresis /Scaron /Scedilla /Tcaron
  /Zacute /hyphen /Zcaron /Zdotaccent
  /degree /aogonek /ogonek /lslash
  /acute /lcaron /sacute /caron
  /cedilla /scaron /scedilla /tcaron
  /zacute /hungarumlaut /zcaron /zdotaccent
% 0300
  /Racute /Aacute /Acircumflex /Abreve
  /Adieresis /Lacute /Cacute /Ccedilla
  /Ccaron /Eacute /Eogonek /Edieresis
  /Ecaron /Iacute /Icircumflex /Dcaron
  /Eth /Nacute /Ncaron /Oacute /Ocircumflex
  /Ohungarumlaut /Odieresis /multiply
  /Rcaron /Uring /Uacute /Uhungarumlaut
  /Udieresis /Yacute /Tcedilla /germandbls
  /racute /aacute /acircumflex /abreve
  /adieresis /lacute /cacute /ccedilla
  /ccaron /eacute /eogonek /edieresis
  /ecaron /iacute /icircumflex /dcaron
  /dbar /nacute /ncaron /oacute
  /ocircumflex /ohungarumlaut /odieresis /divide
  /rcaron /uring /uacute /uhungarumlaut
  /udieresis /yacute /tcedilla /dotaccent
] def
%%EndResource
%
% ----------------------------------------------- ISO 8859-2 encoding vector
%
%%BeginResource: encoding ISOLatin2Encoding
/ISOLatin2Encoding [
  /.notdef /.notdef /.notdef /.notdef 
  /.notdef /.notdef /.notdef /.notdef
  /.notdef /.notdef /.notdef /.notdef 
  /.notdef /.notdef /.notdef /.notdef
  /.notdef /.notdef /.notdef /.notdef
  /.notdef /.notdef /.notdef /.notdef
  /.notdef /.notdef /.notdef /.notdef 
  /.notdef /.notdef /.notdef /.notdef
  /space  /exclam /quotedbl /numbersign
  /dollar /percent /ampersand /quoteright
  /parenleft /parenright /asterisk /plus 
  /comma /minus /period /slash
  /zero /one /two /three 
  /four /five /six /seven
  /eight /nine /colon /semicolon 
  /less /equal /greater /question
% 0100
  /at /A /B /C 
  /D /E /F /G
  /H /I /J /K 
  /L /M /N /O
  /P /Q /R /S 
  /T /U /V /W
  /X /Y /Z /bracketleft 
  /backslash /bracketright /asciicircum /underscore
  /quoteleft /a /b /c 
  /d /e /f /g
  /h /i /j /k 
  /l /m /n /o
  /p /q /r /s 
  /t /u /v /w
  /x /y /z /braceleft 
  /bar /braceright /asciitilde /.notdef
% 0200
  /.notdef /.notdef /.notdef /.notdef 
  /.notdef /.notdef /.notdef /.notdef
  /.notdef /.notdef /.notdef /.notdef 
  /.notdef /.notdef /.notdef /.notdef
  /.notdef /.notdef /.notdef /.notdef 
  /.notdef /.notdef /.notdef /.notdef
  /.notdef /.notdef /.notdef /.notdef 
  /.notdef /.notdef /.notdef /.notdef
  /space /Aogonek /breve /Lslash 
  /currency /Lcaron /Sacute /section
  /dieresis /Scaron /Scedilla /Tcaron 
  /Zacute /hyphen /Zcaron /Zdotaccent
  /degree /aogonek /ogonek /lslash 
  /acute /lcaron /sacute /caron
  /cedilla /scaron /scedilla /tcaron 
  /zacute /hungarumlaut /zcaron /zdotaccent
% 0300
  /Racute /Aacute /Acircumflex /Abreve 
  /Adieresis /Lacute /Cacute /Ccedilla
  /Ccaron /Eacute /Eogonek /Edieresis 
  /Ecaron /Iacute /Icircumflex /Dcaron
  /Dbar /Nacute /Ncaron /Oacute 
  /Ocircumflex /Ohungarumlaut /Odieresis /multiply
  /Rcaron /Uring /Uacute /Uhungarumlaut 
  /Udieresis /Yacute /Tcedilla /germandbls
  /racute /aacute /acircumflex /abreve 
  /adieresis /lacute /cacute /ccedilla
  /ccaron /eacute /eogonek /edieresis 
  /ecaron /iacute /icircumflex /dcaron
  /dbar /nacute /ncaron /oacute 
  /ocircumflex /ohungarumlaut /odieresis /divide
  /rcaron /uring /uacute /uhungarumlaut 
  /udieresis /yacute /tcedilla /dotaccent
] def
%%EndResource
%
% ------------------------------ AvantGarde composite ISO 8859-2 characters
%
%%BeginResource: font AvantGarde-Book-Ogonki
/AvantGarde-Book /AvantGarde-Book-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 181 163 27] put
dup /Aring [65 204 148 31] put
dup /Atilde [65 151 163 29] put
dup /Ecircumflex [69 17 163 28] put
dup /Egrave [69 79 163 27] put
dup /Idieresis [73 -71 163 168] put
dup /Igrave [73 -116 163 27] put
dup /Ntilde [78 151 163 29] put
dup /Ograve [79 246 163 27] put
dup /Otilde [79 215 163 29] put
dup /Ucircumflex [85 77 163 28] put
dup /Ugrave [85 119 163 27] put
dup /Ydieresis [89 112 163 168] put
dup /agrave [97 153 0 27] put
dup /aring [97 176 0 31] put
dup /atilde [97 122 0 29] put
dup /ecircumflex [101 74 0 28] put
dup /egrave [101 136 0 27] put
dup /idieresis [136 -84 0 168] put
dup /igrave [136 -129 0 27] put
dup /ntilde [110 86 0 29] put
dup /ograve [111 139 0 27] put
dup /otilde [111 108 0 29] put
dup /ucircumflex [117 53 0 28] put
dup /ugrave [117 95 0 27] put
dup /ydieresis [121 84 0 168] put
dup /Abreve [65 143 213 162] put
dup /Aogonek [65 393 0 178] put
dup /abreve [97 115 0 162] put
dup /aogonek [97 301 0 178] put
dup /Cacute [67 219 181 180] put
dup /Ccaron [67 228 161 183] put
dup /cacute [99 136 0 180] put
dup /ccaron [99 100 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 121 161 183] put
dup /dcaron [100 540 74 39] put
dup /dbar [100 339 336 173] put
dup /Ecaron [69 17 161 183] put
dup /Edotaccent [69 157 161 255] put
dup /Eogonek [69 117 0 178] put
dup /ecaron [101 74 0 183] put
dup /edotaccent [101 214 0 255] put
dup /eogonek [101 174 0 178] put
dup /Gbreve [71 209 149 162] put
dup /gbreve [103 110 0 162] put
dup /Iogonek [73 -38 0 178] put
dup /iogonek [105 -51 0 178] put
dup /Lcaron [76 72 74 39] put
dup /Lacute [76 43 181 180] put
dup /lcaron [108 57 74 39] put
dup /lacute [108 -64 181 180] put
dup /Nacute [78 226 181 180] put
dup /Ncaron [78 119 161 183] put
dup /nacute [110 140 0 180] put
dup /ncaron [110 54 0 183] put
dup /Ohungarumlaut [79 231 167 189] put
dup /ohungarumlaut [111 113 0 189] put
dup /Rcaron [82 52 161 183] put
dup /Racute [82 160 181 180] put
dup /rcaron [114 -100 0 183] put
dup /racute [114 -14 0 180] put
dup /Sacute [83 61 181 180] put
dup /Scedilla [83 87 0 184] put
dup /sacute [115 6 0 180] put
dup /scedilla [115 32 0 184] put
dup /Tcedilla [84 92 0 184] put
dup /Tcaron [84 -38 161 183] put
dup /tcaron [116 252 0 39] put
dup /tcedilla [116 102 0 184] put
dup /Uring [85 161 118 31] put
dup /Uhungarumlaut [85 124 167 189] put
dup /Umacron [85 85 -736 30] put
dup /Uogonek [85 176 0 178] put
dup /uring [117 138 0 31] put
dup /uhungarumlaut [117 56 0 189] put
dup /umacron [117 61 0 30] put
dup /uogonek [117 153 0 178] put
dup /Zacute [90 52 181 180] put
dup /Zdotaccent [90 129 160 255] put
dup /zacute [122 48 0 180] put
dup /zdotaccent [122 101 0 255] put
makeComposite
%%EndResource
%%BeginResource: font AvantGarde-BookOblique-Ogonki
/AvantGarde-BookOblique /AvantGarde-BookOblique-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 211 163 27] put
dup /Aring [65 231 148 31] put
dup /Atilde [65 181 163 29] put
dup /Ecircumflex [69 47 163 28] put
dup /Egrave [69 109 163 27] put
dup /Idieresis [73 -41 163 168] put
dup /Igrave [73 -86 163 27] put
dup /Ntilde [78 181 163 29] put
dup /Ograve [79 276 163 27] put
dup /Otilde [79 245 163 29] put
dup /Ucircumflex [85 107 163 28] put
dup /Ugrave [85 149 163 27] put
dup /Ydieresis [89 142 163 168] put
dup /agrave [97 153 0 27] put
dup /aring [97 176 0 31] put
dup /atilde [97 122 0 29] put
dup /ecircumflex [101 74 0 28] put
dup /egrave [101 136 0 27] put
dup /idieresis [136 -84 0 168] put
dup /igrave [136 -129 0 27] put
dup /ntilde [110 86 0 29] put
dup /ograve [111 139 0 27] put
dup /otilde [111 108 0 29] put
dup /ucircumflex [117 53 0 28] put
dup /ugrave [117 95 0 27] put
dup /ydieresis [121 84 0 168] put
dup /Abreve [65 180 213 162] put
dup /Aogonek [65 386 0 178] put
dup /abreve [97 115 0 162] put
dup /aogonek [97 297 0 178] put
dup /Cacute [67 250 181 180] put
dup /Ccaron [67 260 161 183] put
dup /cacute [99 136 0 180] put
dup /ccaron [99 102 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 149 161 183] put
dup /dcaron [100 580 74 39] put
dup /dbar [100 405 336 173] put
dup /Ecaron [69 45 161 183] put
dup /Edotaccent [69 185 161 255] put
dup /Eogonek [69 117 0 178] put
dup /ecaron [101 74 0 183] put
dup /edotaccent [101 214 0 255] put
dup /eogonek [101 174 0 178] put
dup /Gbreve [71 235 149 162] put
dup /gbreve [103 110 0 162] put
dup /Iogonek [73 -38 0 178] put
dup /iogonek [105 -51 0 178] put
dup /Lcaron [76 112 74 39] put
dup /Lacute [76 74 181 180] put
dup /lcaron [108 97 74 39] put
dup /lacute [108 -32 181 180] put
dup /Nacute [78 259 181 180] put
dup /Ncaron [78 147 161 183] put
dup /nacute [110 141 0 180] put
dup /ncaron [110 54 0 183] put
dup /Ohungarumlaut [79 264 167 189] put
dup /ohungarumlaut [111 117 0 189] put
dup /Rcaron [82 80 161 183] put
dup /Racute [82 193 181 180] put
dup /rcaron [114 -100 0 183] put
dup /racute [114 -13 0 180] put
dup /Sacute [83 92 181 180] put
dup /Scedilla [83 87 0 184] put
dup /sacute [115 6 0 180] put
dup /scedilla [115 32 0 184] put
dup /Tcedilla [84 94 0 184] put
dup /Tcaron [84 -10 161 183] put
dup /tcaron [116 256 0 39] put
dup /tcedilla [116 105 0 184] put
dup /Uring [85 181 118 31] put
dup /Uhungarumlaut [85 157 167 189] put
dup /Umacron [85 -44 -736 30] put
dup /Uogonek [85 176 0 178] put
dup /uring [117 138 0 31] put
dup /uhungarumlaut [117 58 0 189] put
dup /umacron [117 61 0 30] put
dup /uogonek [117 153 0 178] put
dup /Zacute [90 83 181 180] put
dup /Zdotaccent [90 157 160 255] put
dup /zacute [122 49 0 180] put
dup /zdotaccent [122 101 0 255] put
makeComposite
%%EndResource
%%BeginResource: font AvantGarde-Demi-Ogonki
/AvantGarde-Demi /AvantGarde-Demi-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 160 170 27] put
dup /Aring [65 190 135 31] put
dup /Atilde [65 130 170 29] put
dup /Ecircumflex [69 -10 170 28] put
dup /Egrave [69 50 170 27] put
dup /Idieresis [73 -110 170 168] put
dup /Igrave [73 -95 170 27] put
dup /Ntilde [78 130 170 29] put
dup /Ograve [79 210 170 27] put
dup /Otilde [79 180 170 29] put
dup /Ucircumflex [85 50 170 28] put
dup /Ugrave [85 75 170 27] put
dup /Ydieresis [89 60 170 168] put
dup /agrave [97 120 0 27] put
dup /aring [97 150 0 31] put
dup /atilde [97 90 0 29] put
dup /ecircumflex [101 50 0 28] put
dup /egrave [101 110 0 27] put
dup /idieresis [136 -130 0 168] put
dup /igrave [136 -115 0 27] put
dup /ntilde [110 60 0 29] put
dup /ograve [111 110 0 27] put
dup /otilde [111 80 0 29] put
dup /ucircumflex [117 30 0 28] put
dup /ugrave [117 55 0 27] put
dup /ydieresis [121 40 0 168] put
dup /Abreve [65 130 255 162] put
dup /Aogonek [65 405 0 178] put
dup /abreve [97 90 0 162] put
dup /aogonek [97 291 0 178] put
dup /Cacute [67 180 176 180] put
dup /Ccaron [67 193 164 183] put
dup /cacute [99 110 0 180] put
dup /ccaron [99 79 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 80 164 183] put
dup /dcaron [100 559 74 39] put
dup /dbar [100 287 303 173] put
dup /Ecaron [69 -10 164 183] put
dup /Edotaccent [69 120 164 255] put
dup /Eogonek [69 90 0 178] put
dup /ecaron [101 50 0 183] put
dup /edotaccent [101 180 0 255] put
dup /eogonek [101 150 0 178] put
dup /Gbreve [71 180 167 162] put
dup /gbreve [103 90 0 162] put
dup /Iogonek [73 -30 0 178] put
dup /iogonek [105 -50 0 178] put
dup /Lcaron [76 150 74 39] put
dup /Lacute [76 10 176 180] put
dup /lcaron [108 128 74 39] put
dup /lacute [108 -62 176 180] put
dup /Nacute [78 213 176 180] put
dup /Ncaron [78 100 164 183] put
dup /nacute [110 118 0 180] put
dup /ncaron [110 30 0 183] put
dup /Ohungarumlaut [79 143 163 189] put
dup /ohungarumlaut [111 34 0 189] put
dup /Rcaron [82 20 164 183] put
dup /Racute [82 133 176 180] put
dup /rcaron [114 -110 0 183] put
dup /racute [114 -22 0 180] put
dup /Sacute [83 50 176 180] put
dup /Scedilla [83 90 0 184] put
dup /sacute [115 10 0 180] put
dup /scedilla [115 50 0 184] put
dup /Tcedilla [84 81 0 184] put
dup /Tcaron [84 -60 164 183] put
dup /tcaron [116 240 0 39] put
dup /tcedilla [116 63 0 184] put
dup /Uring [85 140 104 31] put
dup /Uhungarumlaut [85 43 163 189] put
dup /Umacron [85 110 -759 30] put
dup /Uogonek [85 150 0 178] put
dup /uring [117 120 0 31] put
dup /uhungarumlaut [117 -21 0 189] put
dup /umacron [117 90 0 30] put
dup /uogonek [117 130 0 178] put
dup /Zacute [90 40 176 180] put
dup /Zdotaccent [90 110 169 255] put
dup /zacute [122 48 0 180] put
dup /zdotaccent [122 90 0 255] put
makeComposite
%%EndResource
%%BeginResource: font AvantGarde-DemiOblique-Ogonki
/AvantGarde-DemiOblique /AvantGarde-DemiOblique-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 192 170 27] put
dup /Aring [65 215 135 31] put
dup /Atilde [65 162 170 29] put
dup /Ecircumflex [69 22 170 28] put
dup /Egrave [69 82 170 27] put
dup /Idieresis [73 -78 170 168] put
dup /Igrave [73 -63 170 27] put
dup /Ntilde [78 162 170 29] put
dup /Ograve [79 242 170 27] put
dup /Otilde [79 212 170 29] put
dup /Ucircumflex [85 82 170 28] put
dup /Ugrave [85 107 170 27] put
dup /Ydieresis [89 92 170 168] put
dup /agrave [97 120 0 27] put
dup /aring [97 150 0 31] put
dup /atilde [97 90 0 29] put
dup /ecircumflex [101 50 0 28] put
dup /egrave [101 110 0 27] put
dup /idieresis [136 -130 0 168] put
dup /igrave [136 -115 0 27] put
dup /ntilde [110 60 0 29] put
dup /ograve [111 110 0 27] put
dup /otilde [111 80 0 29] put
dup /ucircumflex [117 30 0 28] put
dup /ugrave [117 55 0 27] put
dup /ydieresis [121 40 0 168] put
dup /Abreve [65 174 255 162] put
dup /Aogonek [65 406 0 178] put
dup /abreve [97 90 0 162] put
dup /aogonek [97 292 0 178] put
dup /Cacute [67 211 176 180] put
dup /Ccaron [67 225 164 183] put
dup /cacute [99 110 0 180] put
dup /ccaron [99 80 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 108 164 183] put
dup /dcaron [100 614 74 39] put
dup /dbar [100 352 303 173] put
dup /Ecaron [69 18 164 183] put
dup /Edotaccent [69 148 164 255] put
dup /Eogonek [69 90 0 178] put
dup /ecaron [101 50 0 183] put
dup /edotaccent [101 180 0 255] put
dup /eogonek [101 150 0 178] put
dup /Gbreve [71 209 167 162] put
dup /gbreve [103 90 0 162] put
dup /Iogonek [73 -30 0 178] put
dup /iogonek [105 -50 0 178] put
dup /Lcaron [76 205 74 39] put
dup /Lacute [76 41 176 180] put
dup /lcaron [108 183 74 39] put
dup /lacute [108 -31 176 180] put
dup /Nacute [78 245 176 180] put
dup /Ncaron [78 128 164 183] put
dup /nacute [110 118 0 180] put
dup /ncaron [110 30 0 183] put
dup /Ohungarumlaut [79 175 163 189] put
dup /ohungarumlaut [111 36 0 189] put
dup /Rcaron [82 48 164 183] put
dup /Racute [82 165 176 180] put
dup /rcaron [114 -110 0 183] put
dup /racute [114 -22 0 180] put
dup /Sacute [83 81 176 180] put
dup /Scedilla [83 90 0 184] put
dup /sacute [115 10 0 180] put
dup /scedilla [115 50 0 184] put
dup /Tcedilla [84 84 0 184] put
dup /Tcaron [84 -32 164 183] put
dup /tcaron [116 261 0 39] put
dup /tcedilla [116 75 0 184] put
dup /Uring [85 158 104 31] put
dup /Uhungarumlaut [85 75 163 189] put
dup /Umacron [85 -23 -759 30] put
dup /Uogonek [85 150 0 178] put
dup /uring [117 120 0 31] put
dup /uhungarumlaut [117 -20 0 189] put
dup /umacron [117 90 0 30] put
dup /uogonek [117 130 0 178] put
dup /Zacute [90 71 176 180] put
dup /Zdotaccent [90 139 169 255] put
dup /zacute [122 48 0 180] put
dup /zdotaccent [122 90 0 255] put
makeComposite
%%EndResource
%
% --------------------------------- Courier composite ISO 8859-2 characters
%
%%BeginResource: font Courier-Bold-Ogonki
/Courier-Bold /Courier-Bold-Ogonki OgonkiEncoding StandardEncoding 111 dict
dup /Agrave [65 -50 123 27] put
dup /Aring [65 -10 123 31] put
dup /Atilde [65 -30 123 29] put
dup /Ecircumflex [69 0 123 28] put
dup /Egrave [69 0 123 27] put
dup /Gcaron [71 10 123 183] put
dup /Idieresis [73 0 123 168] put
dup /Igrave [73 0 123 27] put
dup /Ntilde [78 0 123 29] put
dup /Ograve [79 0 123 27] put
dup /Otilde [79 0 123 29] put
dup /Ucircumflex [85 0 123 28] put
dup /Ugrave [85 -30 123 27] put
dup /Ydieresis [89 0 123 168] put
dup /agrave [97 -30 0 27] put
dup /aring [97 0 0 31] put
dup /atilde [97 0 0 29] put
dup /ecircumflex [101 0 0 28] put
dup /egrave [101 0 0 27] put
dup /gcaron [103 -40 0 183] put
dup /idieresis [136 -40 0 168] put
dup /igrave [136 0 0 27] put
dup /ntilde [110 0 0 29] put
dup /ograve [111 0 0 27] put
dup /otilde [111 0 0 29] put
dup /ucircumflex [117 -20 0 28] put
dup /ugrave [117 -30 0 27] put
dup /ydieresis [121 10 0 168] put
dup /abreve [97 0 0 162] put
dup /Abreve [65 0 130 162] put
dup /amacron [97 0 0 30] put
dup /Amacron [65 0 130 30] put
dup /Aogonek [65 200 0 178] put
dup /aogonek [97 200 0 178] put
dup /cacute [99 0 0 180] put
dup /Cacute [67 0 130 180] put
dup /ccaron [99 18 0 183] put
dup /Ccaron [67 18 130 183] put
dup /ccircumflex [99 18 0 28] put
dup /Ccircumflex [67 18 130 28] put
dup /cdotaccent [99 0 0 255] put
dup /Cdotaccent [67 0 130 255] put
dup /dbar [100 200 250 173] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 0 130 183] put
dup /dcaron [100 30 195 183] put
dup /ecaron [101 0 0 183] put
dup /Ecaron [69 0 130 183] put
dup /edotaccent [101 0 0 255] put
dup /Edotaccent [69 0 130 255] put
dup /emacron [101 0 0 30] put
dup /Emacron [69 0 130 30] put
dup /Eogonek [69 0 0 178] put
dup /eogonek [101 0 0 178] put
dup /gacute [103 0 0 180] put
dup /gbreve [103 0 0 162] put
dup /Gbreve [71 18 130 162] put
dup /gcircumflex [103 0 0 28] put
dup /Gcircumflex [71 18 130 28] put
dup /gdotaccent [103 0 0 255] put
dup /Gdotaccent [71 18 130 255] put
dup /hcircumflex [104 -20 195 28] put
dup /Hcircumflex [72 0 130 28] put
dup /Iogonek [73 20 0 178] put
dup /iogonek [105 20 0 178] put
dup /Idotaccent [73 0 130 255] put
dup /imacron [136 0 0 30] put
dup /Imacron [73 0 130 30] put
dup /itilde [136 0 0 29] put
dup /Itilde [73 0 130 29] put
dup /Jcircumflex [74 85 130 28] put
dup /Lacute [76 -100 130 180] put
dup /lacute [108 -20 195 180] put
dup /Lcaron [76 -100 130 183] put
dup /lcaron [108 0 195 183] put
dup /nacute [110 0 0 180] put
dup /Nacute [78 0 130 180] put
dup /ncaron [110 0 0 183] put
dup /Ncaron [78 0 130 183] put
dup /ohungarumlaut [111 0 0 189] put
dup /Ohungarumlaut [79 0 130 189] put
dup /omacron [111 0 0 30] put
dup /Omacron [79 0 130 30] put
dup /racute [114 0 0 180] put
dup /Racute [82 0 130 180] put
dup /rcaron [114 0 0 183] put
dup /Rcaron [82 0 130 183] put
dup /sacute [115 0 0 180] put
dup /Sacute [83 0 130 180] put
dup /scircumflex [115 0 0 28] put
dup /Scircumflex [83 0 130 28] put
dup /tcaron [116 0 107 183] put
dup /Tcaron [84 0 130 183] put
dup /Tcedilla [84 0 0 184] put
dup /tcedilla [116 0 0 184] put
dup /ubreve [117 0 0 162] put
dup /Ubreve [85 0 130 162] put
dup /uhungarumlaut [117 0 0 189] put
dup /Uhungarumlaut [85 0 130 189] put
dup /umacron [117 0 0 30] put
dup /Umacron [85 0 130 30] put
dup /uogonek [117 109 0 178] put
dup /Uogonek [85 5 23 178] put
dup /uring [117 0 0 31] put
dup /Uring [85 0 130 31] put
dup /utilde [117 0 0 29] put
dup /Utilde [85 0 130 29] put
dup /zacute [122 0 0 180] put
dup /Zacute [90 0 130 180] put
dup /zdotaccent [122 0 0 255] put
dup /Zdotaccent [90 0 130 255] put
makeComposite
%%EndResource
%%BeginResource: font Courier-BoldOblique-Ogonki
/Courier-BoldOblique /Courier-BoldOblique-Ogonki OgonkiEncoding StandardEncoding 111 dict
dup /Agrave [65 -24 123 27] put
dup /Aring [65 16 123 31] put
dup /Atilde [65 -4 123 29] put
dup /Ecircumflex [69 26 123 28] put
dup /Egrave [69 26 123 27] put
dup /Gcaron [71 36 123 183] put
dup /Idieresis [73 26 123 168] put
dup /Igrave [73 26 123 27] put
dup /Ntilde [78 26 123 29] put
dup /Ograve [79 26 123 27] put
dup /Otilde [79 26 123 29] put
dup /Ucircumflex [85 26 123 28] put
dup /Ugrave [85 -4 123 27] put
dup /Ydieresis [89 26 123 168] put
dup /agrave [97 -30 0 27] put
dup /aring [97 0 0 31] put
dup /atilde [97 0 0 29] put
dup /ecircumflex [101 0 0 28] put
dup /egrave [101 0 0 27] put
dup /gcaron [103 -40 0 183] put
dup /idieresis [136 -40 0 168] put
dup /igrave [136 0 0 27] put
dup /ntilde [110 0 0 29] put
dup /ograve [111 0 0 27] put
dup /otilde [111 0 0 29] put
dup /ucircumflex [117 -20 0 28] put
dup /ugrave [117 -30 0 27] put
dup /ydieresis [121 10 0 168] put
dup /Abreve [65 -18 130 162] put
dup /abreve [97 0 0 162] put
dup /Amacron [65 -15 130 30] put
dup /amacron [97 0 0 30] put
dup /Aogonek [65 200 0 178] put
dup /aogonek [97 200 0 178] put
dup /cacute [99 0 0 180] put
dup /Cacute [67 30 130 180] put
dup /ccaron [99 0 0 183] put
dup /Ccaron [67 30 130 183] put
dup /ccircumflex [99 0 0 28] put
dup /Ccircumflex [67 30 130 28] put
dup /cdotaccent [99 0 0 255] put
dup /Cdotaccent [67 30 130 255] put
dup /dbar [100 200 250 173] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 -12 130 183] put
dup /dcaron [100 35 178 183] put
dup /ecaron [101 0 0 183] put
dup /Ecaron [69 30 130 183] put
dup /edotaccent [101 0 0 255] put
dup /Edotaccent [69 30 130 255] put
dup /emacron [101 0 0 30] put
dup /Emacron [69 30 130 30] put
dup /Eogonek [69 0 0 178] put
dup /eogonek [101 0 0 178] put
dup /gacute [103 0 0 180] put
dup /gbreve [103 0 0 162] put
dup /Gbreve [71 30 130 162] put
dup /gcircumflex [103 0 0 28] put
dup /Gcircumflex [71 30 130 28] put
dup /gdotaccent [103 0 0 255] put
dup /Gdotaccent [71 30 130 255] put
dup /hcircumflex [104 0 178 28] put
dup /Hcircumflex [72 30 130 28] put
dup /Idotaccent [73 30 130 255] put
dup /imacron [136 0 0 30] put
dup /Imacron [73 30 130 30] put
dup /Iogonek [73 20 0 178] put
dup /iogonek [105 20 0 178] put
dup /itilde [136 0 0 29] put
dup /Itilde [73 30 130 29] put
dup /Jcircumflex [74 95 130 28] put
dup /Lacute [76 -88 130 180] put
dup /lacute [108 0 178 180] put
dup /Lcaron [76 -88 130 183] put
dup /lcaron [108 0 178 183] put
dup /nacute [110 0 0 180] put
dup /Nacute [78 30 130 180] put
dup /ncaron [110 0 0 183] put
dup /Ncaron [78 30 130 183] put
dup /ohungarumlaut [111 0 0 189] put
dup /Ohungarumlaut [79 30 130 189] put
dup /omacron [111 0 0 30] put
dup /Omacron [79 30 130 30] put
dup /racute [114 0 0 180] put
dup /Racute [82 30 130 180] put
dup /rcaron [114 0 0 183] put
dup /Rcaron [82 30 130 183] put
dup /sacute [115 0 0 180] put
dup /Sacute [83 30 130 180] put
dup /scircumflex [115 0 0 28] put
dup /Scircumflex [83 30 130 28] put
dup /tcaron [116 -59 106 183] put
dup /Tcaron [84 30 130 183] put
dup /Tcedilla [84 0 0 184] put
dup /tcedilla [116 0 0 184] put
dup /ubreve [117 0 0 162] put
dup /Ubreve [85 30 130 162] put
dup /uhungarumlaut [117 0 0 189] put
dup /Uhungarumlaut [85 30 130 189] put
dup /umacron [117 0 0 30] put
dup /Umacron [85 30 130 30] put
dup /Uogonek [85 0 7 178] put
dup /uogonek [117 108 0 178] put
dup /uring [117 0 0 31] put
dup /Uring [85 30 130 31] put
dup /utilde [117 0 0 29] put
dup /Utilde [85 30 130 29] put
dup /zacute [122 0 0 180] put
dup /Zacute [90 30 130 180] put
dup /zdotaccent [122 0 0 255] put
dup /Zdotaccent [90 30 130 255] put
makeComposite
%%EndResource
%%BeginResource: font Courier-Oblique-Ogonki
/Courier-Oblique /Courier-Oblique-Ogonki OgonkiEncoding StandardEncoding 111 dict
dup /Agrave [65 -4 121 27] put
dup /Aring [65 12 126 31] put
dup /Atilde [65 27 126 29] put
dup /Ecircumflex [69 26 121 28] put
dup /Egrave [69 26 121 27] put
dup /Gcaron [71 29 136 183] put
dup /Idieresis [73 29 136 168] put
dup /Igrave [73 26 121 27] put
dup /Ntilde [78 27 126 29] put
dup /Ograve [79 26 121 27] put
dup /Otilde [79 27 126 29] put
dup /Ucircumflex [85 26 121 28] put
dup /Ugrave [85 -4 121 27] put
dup /Ydieresis [89 29 136 168] put
dup /agrave [97 0 0 27] put
dup /aring [97 0 0 31] put
dup /atilde [97 0 0 29] put
dup /ecircumflex [101 0 0 28] put
dup /egrave [101 0 0 27] put
dup /gcaron [103 -30 0 183] put
dup /idieresis [136 -30 0 168] put
dup /igrave [136 -30 0 27] put
dup /ntilde [110 0 0 29] put
dup /ograve [111 0 0 27] put
dup /otilde [111 0 0 29] put
dup /ucircumflex [117 -10 0 28] put
dup /ugrave [117 -30 0 27] put
dup /ydieresis [121 -10 0 168] put
dup /abreve [97 0 0 162] put
dup /Abreve [65 0 133 162] put
dup /amacron [97 0 0 30] put
dup /Amacron [65 0 133 30] put
dup /Aogonek [65 200 0 178] put
dup /aogonek [97 200 0 178] put
dup /cacute [99 0 0 180] put
dup /Cacute [67 53 133 180] put
dup /ccaron [99 0 0 183] put
dup /Ccaron [67 53 133 183] put
dup /ccircumflex [99 0 2 28] put
dup /Ccircumflex [67 53 133 28] put
dup /cdotaccent [99 0 0 255] put
dup /Cdotaccent [67 53 133 255] put
dup /dbar [100 200 250 173] put
dup /Dbar [208 0 0 160] put
dup /dcaron [100 20 182 183] put
dup /Dcaron [68 33 133 183] put
dup /ecaron [101 0 0 183] put
dup /Ecaron [69 53 133 183] put
dup /edotaccent [101 0 0 255] put
dup /Edotaccent [69 53 133 255] put
dup /emacron [101 0 0 30] put
dup /Emacron [69 53 133 30] put
dup /Eogonek [69 0 0 178] put
dup /eogonek [101 0 0 178] put
dup /gacute [103 -10 0 180] put
dup /gbreve [103 -10 0 162] put
dup /Gbreve [71 53 133 162] put
dup /gcircumflex [103 -10 0 28] put
dup /Gcircumflex [71 53 133 28] put
dup /gdotaccent [103 0 0 255] put
dup /Gdotaccent [71 53 186 255] put
dup /hcircumflex [104 0 182 28] put
dup /Hcircumflex [72 30 133 28] put
dup /Idotaccent [73 30 133 255] put
dup /imacron [136 0 0 30] put
dup /Imacron [73 30 133 30] put
dup /iogonek [105 20 0 178] put
dup /Iogonek [73 20 0 178] put
dup /itilde [136 0 0 29] put
dup /Itilde [73 30 133 29] put
dup /Jcircumflex [74 98 133 28] put
dup /Lacute [76 -83 133 180] put
dup /lacute [108 0 182 180] put
dup /Lcaron [76 -83 133 183] put
dup /lcaron [108 0 182 183] put
dup /nacute [110 0 0 180] put
dup /Nacute [78 53 133 180] put
dup /ncaron [110 0 0 183] put
dup /Ncaron [78 53 133 183] put
dup /ohungarumlaut [111 0 0 189] put
dup /Ohungarumlaut [79 53 133 189] put
dup /omacron [111 0 0 30] put
dup /Omacron [79 53 133 30] put
dup /racute [114 0 0 180] put
dup /Racute [82 53 133 180] put
dup /rcaron [114 0 0 183] put
dup /Rcaron [82 40 133 183] put
dup /sacute [115 0 0 180] put
dup /Sacute [83 53 133 180] put
dup /scircumflex [115 0 0 28] put
dup /Scircumflex [83 53 133 28] put
dup /tcaron [116 -65 118 183] put
dup /Tcaron [84 40 133 183] put
dup /Tcedilla [84 0 0 184] put
dup /tcedilla [116 0 0 184] put
dup /ubreve [117 0 0 162] put
dup /Ubreve [85 53 133 162] put
dup /uhungarumlaut [117 0 0 189] put
dup /Uhungarumlaut [85 53 133 189] put
dup /umacron [117 0 0 30] put
dup /Umacron [85 53 133 30] put
dup /uogonek [117 120 0 178] put
dup /Uogonek [85 5 15 178] put
dup /uring [117 -30 0 31] put
dup /Uring [85 53 133 31] put
dup /utilde [117 0 0 29] put
dup /Utilde [85 53 133 29] put
dup /zacute [122 0 0 180] put
dup /Zacute [90 40 133 180] put
dup /zdotaccent [122 0 0 255] put
dup /Zdotaccent [90 40 133 255] put
makeComposite
%%EndResource
%%BeginResource: font Courier-Ogonki
/Courier /Courier-Ogonki OgonkiEncoding StandardEncoding 111 dict
dup /Agrave [65 -30 121 27] put
dup /Aring [65 -15 126 31] put
dup /Atilde [65 0 126 29] put
dup /Ecircumflex [69 0 121 28] put
dup /Egrave [69 0 121 27] put
dup /Gcaron [71 0 136 183] put
dup /Idieresis [73 0 136 168] put
dup /Igrave [73 0 121 27] put
dup /Ntilde [78 0 126 29] put
dup /Ograve [79 0 121 27] put
dup /Otilde [79 0 126 29] put
dup /Ucircumflex [85 0 121 28] put
dup /Ugrave [85 -30 121 27] put
dup /Ydieresis [89 0 136 168] put
dup /agrave [97 0 0 27] put
dup /aring [97 0 0 31] put
dup /atilde [97 0 0 29] put
dup /ecircumflex [101 0 0 28] put
dup /egrave [101 0 0 27] put
dup /gcaron [103 -30 0 183] put
dup /idieresis [136 -30 0 168] put
dup /igrave [136 -30 0 27] put
dup /ntilde [110 0 0 29] put
dup /ograve [111 0 0 27] put
dup /otilde [111 0 0 29] put
dup /ucircumflex [117 -10 0 28] put
dup /ugrave [117 -30 0 27] put
dup /ydieresis [121 -10 0 168] put
dup /abreve [97 0 0 162] put
dup /Abreve [65 0 133 162] put
dup /amacron [97 0 0 30] put
dup /Amacron [65 0 133 30] put
dup /Aogonek [65 200 0 178] put
dup /aogonek [97 200 0 178] put
dup /cacute [99 17 0 180] put
dup /Cacute [67 30 133 180] put
dup /ccaron [99 17 0 183] put
dup /Ccaron [67 30 133 183] put
dup /ccircumflex [99 17 2 28] put
dup /Ccircumflex [67 30 133 28] put
dup /cdotaccent [99 0 0 255] put
dup /Cdotaccent [67 30 133 255] put
dup /dbar [100 200 250 173] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 0 133 183] put
dup /dcaron [100 17 156 183] put
dup /ecaron [101 0 0 183] put
dup /Ecaron [69 0 133 183] put
dup /edotaccent [101 0 0 255] put
dup /Edotaccent [69 0 133 255] put
dup /Emacron [69 0 133 30] put
dup /emacron [101 17 0 30] put
dup /Eogonek [69 100 0 178] put
dup /eogonek [101 100 0 178] put
dup /gacute [103 0 0 180] put
dup /gbreve [103 0 0 162] put
dup /Gbreve [71 30 133 162] put
dup /gcircumflex [103 0 0 28] put
dup /Gcircumflex [71 30 133 28] put
dup /gdotaccent [103 0 0 255] put
dup /Gdotaccent [71 0 133 255] put
dup /Hcircumflex [72 0 133 28] put
dup /hcircumflex [104 0 164 28] put
dup /Idotaccent [73 0 133 255] put
dup /imacron [136 0 0 30] put
dup /Imacron [73 0 133 30] put
dup /iogonek [105 20 0 178] put
dup /Iogonek [73 20 0 178] put
dup /itilde [136 0 0 29] put
dup /Itilde [73 0 133 29] put
dup /Jcircumflex [74 100 133 28] put
dup /Lacute [76 -100 133 180] put
dup /lacute [108 -12 147 180] put
dup /Lcaron [76 -100 133 183] put
dup /lcaron [108 -12 144 183] put
dup /nacute [110 0 0 180] put
dup /Nacute [78 0 133 180] put
dup /ncaron [110 0 0 183] put
dup /Ncaron [78 0 133 183] put
dup /ohungarumlaut [111 0 0 189] put
dup /Ohungarumlaut [79 0 133 189] put
dup /omacron [111 0 0 30] put
dup /Omacron [79 0 133 30] put
dup /racute [114 0 0 180] put
dup /Racute [82 0 133 180] put
dup /rcaron [114 0 0 183] put
dup /Rcaron [82 0 133 183] put
dup /sacute [115 0 0 180] put
dup /Sacute [83 0 133 180] put
dup /scircumflex [115 0 0 28] put
dup /Scircumflex [83 0 133 28] put
dup /tcaron [116 -77 92 183] put
dup /Tcaron [84 0 133 183] put
dup /Tcedilla [84 0 0 184] put
dup /tcedilla [116 0 0 184] put
dup /ubreve [117 0 0 162] put
dup /Ubreve [85 0 133 162] put
dup /uhungarumlaut [117 0 0 189] put
dup /Uhungarumlaut [85 0 133 189] put
dup /umacron [117 0 0 30] put
dup /Umacron [85 0 133 30] put
dup /uogonek [117 120 0 178] put
dup /Uogonek [85 5 20 178] put
dup /uring [117 0 0 31] put
dup /Uring [85 0 133 31] put
dup /utilde [117 0 0 29] put
dup /Utilde [85 0 133 29] put
dup /zacute [122 0 0 180] put
dup /Zacute [90 0 133 180] put
dup /zdotaccent [122 0 0 255] put
dup /Zdotaccent [90 0 133 255] put
makeComposite
%%EndResource
%
% ------------------------------- Helvetica composite ISO 8859-2 characters
%
%%BeginResource: font Helvetica-Oblique-Ogonki
/Helvetica-Oblique /Helvetica-Oblique-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Ydieresis [89 167 204 168] put
dup /ydieresis [121 83 0 168] put
dup /Ucircumflex [85 194 204 28] put
dup /Ugrave [85 194 204 27] put
dup /ucircumflex [117 111 0 28] put
dup /ugrave [117 111 0 27] put
dup /Idieresis [73 -27 204 168] put
dup /Igrave [73 -27 204 27] put
dup /idieresis [136 -27 0 168] put
dup /igrave [136 -27 0 27] put
dup /Ecircumflex [69 167 204 28] put
dup /Egrave [69 167 204 27] put
dup /ecircumflex [101 111 0 28] put
dup /egrave [101 111 0 27] put
dup /Agrave [65 167 204 27] put
dup /agrave [97 111 0 27] put
dup /Ograve [79 222 204 27] put
dup /ograve [111 111 0 27] put
dup /Atilde [65 167 204 29] put
dup /atilde [97 111 0 29] put
dup /Ntilde [78 194 204 29] put
dup /ntilde [110 111 0 29] put
dup /Otilde [79 222 204 29] put
dup /otilde [111 111 0 29] put
dup /Aring [65 167 204 31] put
dup /aring [97 111 0 31] put
dup /Abreve [65 210 207 162] put
dup /Aogonek [65 403 0 178] put
dup /abreve [97 111 0 162] put
dup /aogonek [97 262 0 178] put
dup /Cacute [67 235 196 180] put
dup /Ccaron [67 302 198 183] put
dup /cacute [99 83 0 180] put
dup /ccaron [99 107 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 236 198 183] put
dup /dcaron [100 499 94 39] put
dup /dbar [100 332 329 173] put
dup /Ecaron [69 209 198 183] put
dup /Edotaccent [69 205 183 255] put
dup /Eogonek [69 167 0 178] put
dup /ecaron [101 111 0 183] put
dup /edotaccent [101 111 0 255] put
dup /eogonek [101 111 0 178] put
dup /Gbreve [71 263 194 162] put
dup /gbreve [103 111 0 162] put
dup /Iogonek [73 -27 0 178] put
dup /iogonek [105 -55 0 178] put
dup /Lcaron [76 198 94 39] put
dup /Lacute [76 152 196 180] put
dup /lcaron [108 156 94 39] put
dup /lacute [108 10 196 180] put
dup /Nacute [78 281 196 180] put
dup /Ncaron [78 236 198 183] put
dup /nacute [110 135 0 180] put
dup /ncaron [110 111 0 183] put
dup /Ohungarumlaut [79 329 196 189] put
dup /ohungarumlaut [111 164 0 189] put
dup /Rcaron [82 236 198 183] put
dup /Racute [82 281 196 180] put
dup /rcaron [114 0 0 183] put
dup /racute [114 24 0 180] put
dup /Sacute [83 208 196 180] put
dup /Scedilla [83 167 0 184] put
dup /sacute [115 83 0 180] put
dup /scedilla [115 83 0 184] put
dup /Tcedilla [84 198 0 184] put
dup /Tcaron [84 181 198 183] put
dup /tcaron [116 215 0 39] put
dup /tcedilla [116 54 0 184] put
dup /Uring [85 235 197 31] put
dup /Uhungarumlaut [85 301 196 189] put
dup /Umacron [85 47 -694 30] put
dup /Uogonek [85 194 0 178] put
dup /uring [117 111 0 31] put
dup /uhungarumlaut [117 135 0 189] put
dup /umacron [117 111 0 30] put
dup /uogonek [117 111 0 178] put
dup /Zacute [90 180 196 180] put
dup /Zdotaccent [90 187 229 255] put
dup /zacute [122 107 0 180] put
dup /zdotaccent [122 83 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Helvetica-Ogonki
/Helvetica /Helvetica-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Ydieresis [89 167 199 168] put
dup /ydieresis [121 83 0 168] put
dup /Ucircumflex [85 194 199 28] put
dup /Ugrave [85 194 199 27] put
dup /ucircumflex [117 111 0 28] put
dup /ugrave [117 111 0 27] put
dup /Idieresis [73 -21 199 168] put
dup /Igrave [73 -21 199 27] put
dup /idieresis [136 -27 0 168] put
dup /igrave [136 -27 0 27] put
dup /Ecircumflex [69 188 199 28] put
dup /Egrave [69 188 199 27] put
dup /ecircumflex [101 117 0 28] put
dup /egrave [101 117 0 27] put
dup /Agrave [65 167 199 27] put
dup /agrave [97 111 0 27] put
dup /Ograve [79 222 199 27] put
dup /ograve [111 111 0 27] put
dup /Atilde [65 167 199 29] put
dup /atilde [97 111 0 29] put
dup /Ntilde [78 200 199 29] put
dup /ntilde [110 117 0 29] put
dup /Otilde [79 222 199 29] put
dup /otilde [111 111 0 29] put
dup /Aring [65 167 199 31] put
dup /aring [97 111 0 31] put
dup /Abreve [65 167 207 162] put
dup /Aogonek [65 400 0 178] put
dup /abreve [97 111 0 162] put
dup /aogonek [97 260 0 178] put
dup /Cacute [67 194 196 180] put
dup /Ccaron [67 257 198 183] put
dup /cacute [99 83 0 180] put
dup /ccaron [99 105 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 194 198 183] put
dup /dcaron [100 440 94 39] put
dup /dbar [100 254 329 173] put
dup /Ecaron [69 167 198 183] put
dup /Edotaccent [69 167 183 255] put
dup /Eogonek [69 167 0 178] put
dup /ecaron [101 111 0 183] put
dup /edotaccent [101 111 0 255] put
dup /eogonek [101 111 0 178] put
dup /Gbreve [71 222 194 162] put
dup /gbreve [103 111 0 162] put
dup /Iogonek [73 -27 0 178] put
dup /iogonek [105 -55 0 178] put
dup /Lcaron [76 139 94 39] put
dup /Lacute [76 111 196 180] put
dup /lcaron [108 97 94 39] put
dup /lacute [108 -34 196 180] put
dup /Nacute [78 234 196 180] put
dup /Ncaron [78 194 198 183] put
dup /nacute [110 132 0 180] put
dup /ncaron [110 111 0 183] put
dup /Ohungarumlaut [79 285 196 189] put
dup /ohungarumlaut [111 159 0 189] put
dup /Rcaron [82 194 198 183] put
dup /Racute [82 234 196 180] put
dup /rcaron [114 0 0 183] put
dup /racute [114 21 0 180] put
dup /Sacute [83 167 196 180] put
dup /Scedilla [83 167 0 184] put
dup /sacute [115 83 0 180] put
dup /scedilla [115 83 0 184] put
dup /Tcedilla [84 196 0 184] put
dup /Tcaron [84 139 198 183] put
dup /tcaron [116 199 0 39] put
dup /tcedilla [116 45 0 184] put
dup /Uring [85 194 197 31] put
dup /Uhungarumlaut [85 257 196 189] put
dup /Umacron [85 194 -694 30] put
dup /Uogonek [85 194 0 178] put
dup /uring [117 111 0 31] put
dup /uhungarumlaut [117 133 0 189] put
dup /umacron [117 111 0 30] put
dup /uogonek [117 111 0 178] put
dup /Zacute [90 139 196 180] put
dup /Zdotaccent [90 139 229 255] put
dup /zacute [122 104 0 180] put
dup /zdotaccent [122 83 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Helvetica-Bold-Ogonki
/Helvetica-Bold /Helvetica-Bold-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Ydieresis [89 167 191 168] put
dup /ydieresis [121 111 0 168] put
dup /Ucircumflex [85 197 191 28] put
dup /Ugrave [85 197 191 27] put
dup /ucircumflex [117 139 0 28] put
dup /ugrave [117 139 0 27] put
dup /Idieresis [73 -27 191 168] put
dup /Igrave [73 -27 191 27] put
dup /idieresis [136 -27 0 168] put
dup /igrave [136 -27 0 27] put
dup /Ecircumflex [69 188 191 28] put
dup /Egrave [69 188 191 27] put
dup /ecircumflex [101 111 0 28] put
dup /egrave [101 111 0 27] put
dup /Agrave [65 197 191 27] put
dup /agrave [97 111 0 27] put
dup /Ograve [79 222 191 27] put
dup /ograve [111 139 0 27] put
dup /Atilde [65 197 191 29] put
dup /atilde [97 111 0 29] put
dup /Ntilde [78 200 191 29] put
dup /ntilde [110 146 0 29] put
dup /Otilde [79 222 191 29] put
dup /otilde [111 139 0 29] put
dup /Aring [65 197 191 31] put
dup /aring [97 111 0 31] put
dup /Abreve [65 194 202 162] put
dup /Aogonek [65 444 0 178] put
dup /abreve [97 111 0 162] put
dup /aogonek [97 270 0 178] put
dup /Cacute [67 194 193 180] put
dup /Ccaron [67 258 190 183] put
dup /cacute [99 111 0 180] put
dup /ccaron [99 135 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 194 190 183] put
dup /dcaron [100 493 73 39] put
dup /dbar [100 302 298 173] put
dup /Ecaron [69 167 190 183] put
dup /Edotaccent [69 167 181 255] put
dup /Eogonek [69 167 0 178] put
dup /ecaron [101 111 0 183] put
dup /edotaccent [101 111 0 255] put
dup /eogonek [101 111 0 178] put
dup /Gbreve [71 222 195 162] put
dup /gbreve [103 139 0 162] put
dup /Iogonek [73 -27 0 178] put
dup /iogonek [105 -27 0 178] put
dup /Lcaron [76 161 73 39] put
dup /Lacute [76 139 193 180] put
dup /lcaron [108 155 73 39] put
dup /lacute [108 -7 193 180] put
dup /Nacute [78 231 193 180] put
dup /Ncaron [78 194 190 183] put
dup /nacute [110 159 0 180] put
dup /ncaron [110 139 0 183] put
dup /Ohungarumlaut [79 286 193 189] put
dup /ohungarumlaut [111 192 0 189] put
dup /Rcaron [82 194 190 183] put
dup /Racute [82 231 193 180] put
dup /rcaron [114 28 0 183] put
dup /racute [114 48 0 180] put
dup /Sacute [83 167 193 180] put
dup /Scedilla [83 167 0 184] put
dup /sacute [115 111 0 180] put
dup /scedilla [115 111 0 184] put
dup /Tcedilla [84 197 0 184] put
dup /Tcaron [84 139 190 183] put
dup /tcaron [116 249 0 39] put
dup /tcedilla [116 86 0 184] put
dup /Uring [85 194 190 31] put
dup /Uhungarumlaut [85 258 193 189] put
dup /Umacron [85 194 -717 30] put
dup /Uogonek [85 194 0 178] put
dup /uring [117 139 0 31] put
dup /uhungarumlaut [117 163 0 189] put
dup /umacron [117 139 0 30] put
dup /uogonek [117 139 0 178] put
dup /Zacute [90 139 193 180] put
dup /Zdotaccent [90 139 206 255] put
dup /zacute [122 103 0 180] put
dup /zdotaccent [122 83 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Helvetica-BoldOblique-Ogonki
/Helvetica-BoldOblique /Helvetica-BoldOblique-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Ydieresis [89 167 187 168] put
dup /ydieresis [121 111 0 168] put
dup /Ucircumflex [85 194 187 28] put
dup /Ugrave [85 194 187 27] put
dup /ucircumflex [117 139 0 28] put
dup /ugrave [117 139 0 27] put
dup /Idieresis [73 -27 187 168] put
dup /Igrave [73 -27 187 27] put
dup /idieresis [136 -27 0 168] put
dup /igrave [136 -27 0 27] put
dup /Ecircumflex [69 167 187 28] put
dup /Egrave [69 167 187 27] put
dup /ecircumflex [101 111 0 28] put
dup /egrave [101 111 0 27] put
dup /Agrave [65 194 187 27] put
dup /agrave [97 111 0 27] put
dup /Ograve [79 222 187 27] put
dup /ograve [111 139 0 27] put
dup /Atilde [65 194 187 29] put
dup /atilde [97 111 0 29] put
dup /Ntilde [78 194 187 29] put
dup /ntilde [110 139 0 29] put
dup /Otilde [79 222 187 29] put
dup /otilde [111 139 0 29] put
dup /Aring [65 194 187 31] put
dup /aring [97 111 0 31] put
dup /Abreve [65 236 202 162] put
dup /Aogonek [65 446 0 178] put
dup /abreve [97 111 0 162] put
dup /aogonek [97 272 0 178] put
dup /Cacute [67 235 193 180] put
dup /Ccaron [67 303 190 183] put
dup /cacute [99 111 0 180] put
dup /ccaron [99 137 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 234 190 183] put
dup /dcaron [100 553 73 39] put
dup /dbar [100 383 298 173] put
dup /Ecaron [69 207 190 183] put
dup /Edotaccent [69 205 181 255] put
dup /Eogonek [69 167 0 178] put
dup /ecaron [101 111 0 183] put
dup /edotaccent [101 111 0 255] put
dup /eogonek [101 111 0 178] put
dup /Gbreve [71 263 195 162] put
dup /gbreve [103 139 0 162] put
dup /Iogonek [73 -27 0 178] put
dup /iogonek [105 -27 0 178] put
dup /Lcaron [76 221 73 39] put
dup /Lacute [76 180 193 180] put
dup /lcaron [108 215 73 39] put
dup /lacute [108 37 193 180] put
dup /Nacute [78 278 193 180] put
dup /Ncaron [78 234 190 183] put
dup /nacute [110 162 0 180] put
dup /ncaron [110 139 0 183] put
dup /Ohungarumlaut [79 332 193 189] put
dup /ohungarumlaut [111 196 0 189] put
dup /Rcaron [82 234 190 183] put
dup /Racute [82 278 193 180] put
dup /rcaron [114 28 0 183] put
dup /racute [114 51 0 180] put
dup /Sacute [83 208 193 180] put
dup /Scedilla [83 167 0 184] put
dup /sacute [115 111 0 180] put
dup /scedilla [115 111 0 184] put
dup /Tcedilla [84 200 0 184] put
dup /Tcaron [84 179 190 183] put
dup /tcaron [116 267 0 39] put
dup /tcedilla [116 94 0 184] put
dup /Uring [85 234 190 31] put
dup /Uhungarumlaut [85 304 193 189] put
dup /Umacron [85 42 -717 30] put
dup /Uogonek [85 194 0 178] put
dup /uring [117 139 0 31] put
dup /uhungarumlaut [117 165 0 189] put
dup /umacron [117 139 0 30] put
dup /uogonek [117 139 0 178] put
dup /Zacute [90 180 193 180] put
dup /Zdotaccent [90 182 206 255] put
dup /zacute [122 106 0 180] put
dup /zdotaccent [122 83 0 255] put
makeComposite
%%EndResource
%
% ------------------------ Helvetica Narrow composite ISO 8859-2 characters
%
%%BeginResource: font Helvetica-Narrow-Bold-Ogonki
/Helvetica-Narrow-Bold /Helvetica-Narrow-Bold-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 160 186 27] put
dup /Aring [65 160 186 31] put
dup /Atilde [65 160 186 29] put
dup /Ecircumflex [69 137 186 28] put
dup /Egrave [69 137 186 27] put
dup /Idieresis [73 -22 186 168] put
dup /Igrave [73 -22 186 27] put
dup /Ntilde [78 160 186 29] put
dup /Ograve [79 183 186 27] put
dup /Otilde [79 183 186 29] put
dup /Ucircumflex [85 160 186 28] put
dup /Ugrave [85 160 186 27] put
dup /Ydieresis [89 137 186 168] put
dup /agrave [97 92 0 27] put
dup /aring [97 92 0 31] put
dup /atilde [97 92 0 29] put
dup /ecircumflex [101 92 0 28] put
dup /egrave [101 92 0 27] put
dup /idieresis [136 -22 0 168] put
dup /igrave [136 -22 0 27] put
dup /ntilde [110 114 0 29] put
dup /ograve [111 114 0 27] put
dup /otilde [111 114 0 29] put
dup /ucircumflex [117 114 0 28] put
dup /ugrave [117 114 0 27] put
dup /ydieresis [121 92 0 168] put
dup /Abreve [65 159 173 162] put
dup /Aogonek [65 373 0 178] put
dup /abreve [97 91 0 162] put
dup /aogonek [97 228 0 178] put
dup /Cacute [67 159 173 180] put
dup /Ccaron [67 212 173 183] put
dup /cacute [99 91 0 180] put
dup /ccaron [99 111 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 159 173 183] put
dup /dcaron [100 406 72 39] put
dup /dbar [100 251 287 173] put
dup /Ecaron [69 137 173 183] put
dup /Edotaccent [69 137 163 255] put
dup /Eogonek [69 137 0 178] put
dup /ecaron [101 91 0 183] put
dup /edotaccent [101 91 0 255] put
dup /eogonek [101 91 0 178] put
dup /Gbreve [71 182 173 162] put
dup /gbreve [103 114 0 162] put
dup /Iogonek [73 -22 0 178] put
dup /iogonek [105 -22 0 178] put
dup /Lcaron [76 129 72 39] put
dup /Lacute [76 114 173 180] put
dup /lcaron [108 125 72 39] put
dup /lacute [108 -2 173 180] put
dup /Nacute [78 198 173 180] put
dup /Ncaron [78 159 173 183] put
dup /nacute [110 134 0 180] put
dup /ncaron [110 114 0 183] put
dup /Ohungarumlaut [79 235 173 189] put
dup /ohungarumlaut [111 158 0 189] put
dup /Rcaron [82 159 173 183] put
dup /Racute [82 198 173 180] put
dup /rcaron [114 23 0 183] put
dup /racute [114 43 0 180] put
dup /Sacute [83 137 173 180] put
dup /Scedilla [83 137 0 184] put
dup /sacute [115 91 0 180] put
dup /scedilla [115 91 0 184] put
dup /Tcedilla [84 162 0 184] put
dup /Tcaron [84 114 173 183] put
dup /tcaron [116 207 0 39] put
dup /tcedilla [116 74 0 184] put
dup /Uring [85 159 147 31] put
dup /Uhungarumlaut [85 212 173 189] put
dup /Umacron [85 159 -678 30] put
dup /Uogonek [85 159 0 178] put
dup /uring [117 114 0 31] put
dup /uhungarumlaut [117 134 0 189] put
dup /umacron [117 114 0 30] put
dup /uogonek [117 114 0 178] put
dup /Zacute [90 114 173 180] put
dup /Zdotaccent [90 114 194 255] put
dup /zacute [122 88 0 180] put
dup /zdotaccent [122 68 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Helvetica-Narrow-BoldOblique-Ogonki
/Helvetica-Narrow-BoldOblique /Helvetica-Narrow-BoldOblique-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 192 186 27] put
dup /Aring [65 192 186 31] put
dup /Atilde [65 192 186 29] put
dup /Ecircumflex [69 169 186 28] put
dup /Egrave [69 169 186 27] put
dup /Idieresis [73 10 186 168] put
dup /Igrave [73 10 186 27] put
dup /Ntilde [78 192 186 29] put
dup /Ograve [79 215 186 27] put
dup /Otilde [79 215 186 29] put
dup /Ucircumflex [85 192 186 28] put
dup /Ugrave [85 192 186 27] put
dup /Ydieresis [89 169 186 168] put
dup /agrave [97 92 0 27] put
dup /aring [97 92 0 31] put
dup /atilde [97 92 0 29] put
dup /ecircumflex [101 92 0 28] put
dup /egrave [101 92 0 27] put
dup /idieresis [136 -22 0 168] put
dup /igrave [136 -22 0 27] put
dup /ntilde [110 114 0 29] put
dup /ograve [111 114 0 27] put
dup /otilde [111 114 0 29] put
dup /ucircumflex [117 114 0 28] put
dup /ugrave [117 114 0 27] put
dup /ydieresis [121 92 0 168] put
dup /Abreve [65 195 173 162] put
dup /Aogonek [65 364 0 178] put
dup /abreve [97 91 0 162] put
dup /aogonek [97 222 0 178] put
dup /Cacute [67 195 173 180] put
dup /Ccaron [67 251 173 183] put
dup /cacute [99 91 0 180] put
dup /ccaron [99 112 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 195 173 183] put
dup /dcaron [100 456 72 39] put
dup /dbar [100 326 287 173] put
dup /Ecaron [69 173 173 183] put
dup /Edotaccent [69 171 163 255] put
dup /Eogonek [69 137 0 178] put
dup /ecaron [101 91 0 183] put
dup /edotaccent [101 91 0 255] put
dup /eogonek [101 91 0 178] put
dup /Gbreve [71 218 173 162] put
dup /gbreve [103 114 0 162] put
dup /Iogonek [73 -22 0 178] put
dup /iogonek [105 -22 0 178] put
dup /Lcaron [76 180 72 39] put
dup /Lacute [76 150 173 180] put
dup /lcaron [108 176 72 39] put
dup /lacute [108 37 173 180] put
dup /Nacute [78 239 173 180] put
dup /Ncaron [78 195 173 183] put
dup /nacute [110 137 0 180] put
dup /ncaron [110 114 0 183] put
dup /Ohungarumlaut [79 274 173 189] put
dup /ohungarumlaut [111 160 0 189] put
dup /Rcaron [82 195 173 183] put
dup /Racute [82 239 173 180] put
dup /rcaron [114 23 0 183] put
dup /racute [114 46 0 180] put
dup /Sacute [83 173 173 180] put
dup /Scedilla [83 137 0 184] put
dup /sacute [115 91 0 180] put
dup /scedilla [115 91 0 184] put
dup /Tcedilla [84 164 0 184] put
dup /Tcaron [84 150 173 183] put
dup /tcaron [116 225 0 39] put
dup /tcedilla [116 79 0 184] put
dup /Uring [85 190 147 31] put
dup /Uhungarumlaut [85 251 173 189] put
dup /Umacron [85 15 -678 30] put
dup /Uogonek [85 159 0 178] put
dup /uring [117 114 0 31] put
dup /uhungarumlaut [117 135 0 189] put
dup /umacron [117 114 0 30] put
dup /uogonek [117 114 0 178] put
dup /Zacute [90 150 173 180] put
dup /Zdotaccent [90 155 194 255] put
dup /zacute [122 91 0 180] put
dup /zdotaccent [122 68 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Helvetica-Narrow-Oblique-Ogonki
/Helvetica-Narrow-Oblique /Helvetica-Narrow-Oblique-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 171 195 27] put
dup /Aring [65 167 175 31] put
dup /Atilde [65 171 195 29] put
dup /Ecircumflex [69 171 195 28] put
dup /Egrave [69 171 195 27] put
dup /Idieresis [73 12 195 168] put
dup /Igrave [73 12 195 27] put
dup /Ntilde [78 202 195 29] put
dup /Ograve [79 217 195 27] put
dup /Otilde [79 217 195 29] put
dup /Ucircumflex [85 194 195 28] put
dup /Ugrave [85 194 195 27] put
dup /Ydieresis [89 171 195 168] put
dup /agrave [97 92 0 27] put
dup /aring [97 92 0 31] put
dup /atilde [97 84 0 29] put
dup /ecircumflex [101 92 0 28] put
dup /egrave [101 92 0 27] put
dup /idieresis [136 -22 0 168] put
dup /igrave [136 -22 0 27] put
dup /ntilde [110 84 0 29] put
dup /ograve [111 92 0 27] put
dup /otilde [111 92 0 29] put
dup /ucircumflex [117 92 0 28] put
dup /ugrave [117 92 0 27] put
dup /ydieresis [121 69 0 168] put
dup /Abreve [65 176 187 162] put
dup /Aogonek [65 326 0 178] put
dup /abreve [97 91 0 162] put
dup /aogonek [97 212 0 178] put
dup /Cacute [67 198 184 180] put
dup /Ccaron [67 253 184 183] put
dup /cacute [99 68 0 180] put
dup /ccaron [99 88 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 198 184 183] put
dup /dcaron [100 423 72 39] put
dup /dbar [100 286 310 173] put
dup /Ecaron [69 176 184 183] put
dup /Edotaccent [69 173 173 255] put
dup /Eogonek [69 137 0 178] put
dup /ecaron [101 91 0 183] put
dup /edotaccent [101 91 0 255] put
dup /eogonek [101 91 0 178] put
dup /Gbreve [71 220 182 162] put
dup /gbreve [103 91 0 162] put
dup /Iogonek [73 -22 0 178] put
dup /iogonek [105 -45 0 178] put
dup /Lcaron [76 168 72 39] put
dup /Lacute [76 130 184 180] put
dup /lcaron [108 141 72 39] put
dup /lacute [108 13 184 180] put
dup /Nacute [78 234 184 180] put
dup /Ncaron [78 198 184 183] put
dup /nacute [110 110 0 180] put
dup /ncaron [110 91 0 183] put
dup /Ohungarumlaut [79 276 184 189] put
dup /ohungarumlaut [111 135 0 189] put
dup /Rcaron [82 198 184 183] put
dup /Racute [82 234 184 180] put
dup /rcaron [114 0 0 183] put
dup /racute [114 19 0 180] put
dup /Sacute [83 176 184 180] put
dup /Scedilla [83 137 0 184] put
dup /sacute [115 68 0 180] put
dup /scedilla [115 68 0 184] put
dup /Tcedilla [84 163 0 184] put
dup /Tcaron [84 153 184 183] put
dup /tcaron [116 191 0 39] put
dup /tcedilla [116 43 0 184] put
dup /Uring [85 193 162 31] put
dup /Uhungarumlaut [85 253 184 189] put
dup /Umacron [85 14 -684 30] put
dup /Uogonek [85 159 0 178] put
dup /uring [117 91 0 31] put
dup /uhungarumlaut [117 111 0 189] put
dup /umacron [117 91 0 30] put
dup /uogonek [117 91 0 178] put
dup /Zacute [90 153 184 180] put
dup /Zdotaccent [90 159 212 255] put
dup /zacute [122 87 0 180] put
dup /zdotaccent [122 68 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Helvetica-Narrow-Ogonki
/Helvetica-Narrow /Helvetica-Narrow-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 137 195 27] put
dup /Aring [65 137 175 31] put
dup /Atilde [65 137 195 29] put
dup /Ecircumflex [69 137 195 28] put
dup /Egrave [69 137 195 27] put
dup /Idieresis [73 -22 195 168] put
dup /Igrave [73 -22 195 27] put
dup /Ntilde [78 168 195 29] put
dup /Ograve [79 183 195 27] put
dup /Otilde [79 183 195 29] put
dup /Ucircumflex [85 160 195 28] put
dup /Ugrave [85 160 195 27] put
dup /Ydieresis [89 137 195 168] put
dup /agrave [97 92 0 27] put
dup /aring [97 92 0 31] put
dup /atilde [97 84 0 29] put
dup /ecircumflex [101 92 0 28] put
dup /egrave [101 92 0 27] put
dup /idieresis [136 -22 0 168] put
dup /igrave [136 -22 0 27] put
dup /ntilde [110 84 0 29] put
dup /ograve [111 92 0 27] put
dup /otilde [111 92 0 29] put
dup /ucircumflex [117 92 0 28] put
dup /ugrave [117 92 0 27] put
dup /ydieresis [121 69 0 168] put
dup /Abreve [65 137 187 162] put
dup /Aogonek [65 333 0 178] put
dup /abreve [97 91 0 162] put
dup /aogonek [97 216 0 178] put
dup /Cacute [67 159 184 180] put
dup /Ccaron [67 211 184 183] put
dup /cacute [99 68 0 180] put
dup /ccaron [99 86 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 159 184 183] put
dup /dcaron [100 375 72 39] put
dup /dbar [100 212 310 173] put
dup /Ecaron [69 137 184 183] put
dup /Edotaccent [69 137 173 255] put
dup /Eogonek [69 137 0 178] put
dup /ecaron [101 91 0 183] put
dup /edotaccent [101 91 0 255] put
dup /eogonek [101 91 0 178] put
dup /Gbreve [71 182 182 162] put
dup /gbreve [103 91 0 162] put
dup /Iogonek [73 -22 0 178] put
dup /iogonek [105 -45 0 178] put
dup /Lcaron [76 120 72 39] put
dup /Lacute [76 91 184 180] put
dup /lcaron [108 93 72 39] put
dup /lacute [108 -29 184 180] put
dup /Nacute [78 190 184 180] put
dup /Ncaron [78 159 184 183] put
dup /nacute [110 107 0 180] put
dup /ncaron [110 91 0 183] put
dup /Ohungarumlaut [79 234 184 189] put
dup /ohungarumlaut [111 131 0 189] put
dup /Rcaron [82 159 184 183] put
dup /Racute [82 190 184 180] put
dup /rcaron [114 0 0 183] put
dup /racute [114 16 0 180] put
dup /Sacute [83 137 184 180] put
dup /Scedilla [83 137 0 184] put
dup /sacute [115 68 0 180] put
dup /scedilla [115 68 0 184] put
dup /Tcedilla [84 162 0 184] put
dup /Tcaron [84 114 184 183] put
dup /tcaron [116 177 0 39] put
dup /tcedilla [116 38 0 184] put
dup /Uring [85 159 162 31] put
dup /Uhungarumlaut [85 211 184 189] put
dup /Umacron [85 159 -684 30] put
dup /Uogonek [85 159 0 178] put
dup /uring [117 91 0 31] put
dup /uhungarumlaut [117 109 0 189] put
dup /umacron [117 91 0 30] put
dup /uogonek [117 91 0 178] put
dup /Zacute [90 114 184 180] put
dup /Zdotaccent [90 114 212 255] put
dup /zacute [122 84 0 180] put
dup /zdotaccent [122 68 0 255] put
makeComposite
%%EndResource
%
% ------------------ New Century Schoolbook composite ISO 8859-2 characters
%
%%BeginResource: font NewCenturySchlbk-Bold-Ogonki
/NewCenturySchlbk-Bold /NewCenturySchlbk-Bold-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 213 227 27] put
dup /Aring [65 213 227 31] put
dup /Atilde [65 213 227 29] put
dup /Ecircumflex [69 213 227 28] put
dup /Egrave [69 213 227 27] put
dup /Idieresis [73 56 227 168] put
dup /Igrave [73 56 227 27] put
dup /Ntilde [78 250 227 29] put
dup /Ograve [79 250 227 27] put
dup /Otilde [79 250 227 29] put
dup /Ucircumflex [85 250 227 28] put
dup /Ugrave [85 250 227 27] put
dup /Ydieresis [89 195 227 168] put
dup /agrave [97 139 0 27] put
dup /aring [97 139 0 31] put
dup /atilde [97 139 0 29] put
dup /ecircumflex [101 121 0 28] put
dup /egrave [101 121 0 27] put
dup /idieresis [136 19 0 168] put
dup /igrave [136 19 0 27] put
dup /ntilde [110 176 0 29] put
dup /ograve [111 139 0 27] put
dup /otilde [111 139 0 29] put
dup /ucircumflex [117 176 0 28] put
dup /ugrave [117 176 0 27] put
dup /ydieresis [121 139 0 168] put
dup /Abreve [65 213 257 162] put
dup /Aogonek [65 412 0 178] put
dup /abreve [97 139 0 162] put
dup /aogonek [97 266 0 178] put
dup /Cacute [67 222 234 180] put
dup /Ccaron [67 290 234 183] put
dup /cacute [99 111 0 180] put
dup /ccaron [99 136 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 250 234 183] put
dup /dcaron [100 642 74 39] put
dup /dbar [100 316 347 173] put
dup /Ecaron [69 213 234 183] put
dup /Edotaccent [69 213 229 255] put
dup /Eogonek [69 213 0 178] put
dup /ecaron [101 120 0 183] put
dup /edotaccent [101 120 0 255] put
dup /eogonek [101 120 0 178] put
dup /Gbreve [71 250 234 162] put
dup /gbreve [103 139 0 162] put
dup /Iogonek [73 55 0 178] put
dup /iogonek [105 18 0 178] put
dup /Lcaron [76 413 57 39] put
dup /Lacute [76 194 234 180] put
dup /lcaron [108 327 74 39] put
dup /lacute [108 34 234 180] put
dup /Nacute [78 297 234 180] put
dup /Ncaron [78 250 234 183] put
dup /nacute [110 201 0 180] put
dup /ncaron [110 176 0 183] put
dup /Ohungarumlaut [79 318 234 189] put
dup /ohungarumlaut [111 194 0 189] put
dup /Rcaron [82 241 234 183] put
dup /Racute [82 288 234 180] put
dup /rcaron [114 93 0 183] put
dup /racute [114 118 0 180] put
dup /Sacute [83 167 234 180] put
dup /Scedilla [83 167 0 184] put
dup /sacute [115 83 0 180] put
dup /scedilla [115 83 0 184] put
dup /Tcedilla [84 263 0 184] put
dup /Tcaron [84 194 234 183] put
dup /tcaron [116 403 0 39] put
dup /tcedilla [116 161 0 184] put
dup /Uring [85 250 198 31] put
dup /Uhungarumlaut [85 318 234 189] put
dup /Umacron [85 250 -664 30] put
dup /Uogonek [85 250 0 178] put
dup /uring [117 176 0 31] put
dup /uhungarumlaut [117 201 0 189] put
dup /umacron [117 176 0 30] put
dup /uogonek [117 176 0 178] put
dup /Zacute [90 167 234 180] put
dup /Zdotaccent [90 167 265 255] put
dup /zacute [122 127 0 180] put
dup /zdotaccent [122 102 0 255] put
makeComposite
%%EndResource
%%BeginResource: font NewCenturySchlbk-BoldItalic-Ogonki
/NewCenturySchlbk-BoldItalic /NewCenturySchlbk-BoldItalic-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 259 225 27] put
dup /Aring [65 229 245 31] put
dup /Atilde [65 259 225 29] put
dup /Ecircumflex [69 296 225 28] put
dup /Egrave [69 296 225 27] put
dup /Idieresis [73 116 225 168] put
dup /Igrave [73 116 225 27] put
dup /Ntilde [78 326 225 29] put
dup /Ograve [79 315 225 27] put
dup /Otilde [79 315 225 29] put
dup /Ucircumflex [85 340 225 28] put
dup /Ugrave [85 340 225 27] put
dup /Ydieresis [89 236 225 168] put
dup /agrave [97 167 0 27] put
dup /aring [97 167 0 31] put
dup /atilde [97 167 0 29] put
dup /ecircumflex [101 93 0 28] put
dup /egrave [101 93 0 27] put
dup /idieresis [136 -2 -7 168] put
dup /igrave [136 -2 -7 27] put
dup /ntilde [110 176 0 29] put
dup /ograve [111 121 0 27] put
dup /otilde [111 121 0 29] put
dup /ucircumflex [117 176 0 28] put
dup /ugrave [117 176 0 27] put
dup /ydieresis [121 93 0 168] put
dup /Abreve [65 280 267 162] put
dup /Aogonek [65 403 0 178] put
dup /abreve [97 167 0 162] put
dup /aogonek [97 294 0 178] put
dup /Cacute [67 282 243 180] put
dup /Ccaron [67 356 250 183] put
dup /cacute [99 102 0 180] put
dup /ccaron [99 126 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 321 250 183] put
dup /dcaron [100 635 74 39] put
dup /dbar [100 424 350 173] put
dup /Ecaron [69 275 250 183] put
dup /Edotaccent [69 271 235 255] put
dup /Eogonek [69 204 0 178] put
dup /ecaron [101 93 0 183] put
dup /edotaccent [101 93 0 255] put
dup /eogonek [101 93 0 178] put
dup /Gbreve [71 311 246 162] put
dup /gbreve [103 139 0 162] put
dup /Iogonek [73 55 0 178] put
dup /iogonek [105 28 0 178] put
dup /Lcaron [76 460 57 39] put
dup /Lacute [76 254 243 180] put
dup /lcaron [108 350 74 39] put
dup /lacute [108 122 243 180] put
dup /Nacute [78 375 243 180] put
dup /Ncaron [78 330 250 183] put
dup /nacute [110 201 0 180] put
dup /ncaron [110 176 0 183] put
dup /Ohungarumlaut [79 391 243 189] put
dup /ohungarumlaut [111 173 0 189] put
dup /Rcaron [82 302 250 183] put
dup /Racute [82 347 243 180] put
dup /rcaron [114 93 0 183] put
dup /racute [114 118 0 180] put
dup /Sacute [83 245 243 180] put
dup /Scedilla [83 176 0 184] put
dup /sacute [115 74 0 180] put
dup /scedilla [115 74 0 184] put
dup /Tcedilla [84 266 0 184] put
dup /Tcaron [84 265 250 183] put
dup /tcaron [116 378 0 39] put
dup /tcedilla [116 151 0 184] put
dup /Uring [85 309 209 31] put
dup /Uhungarumlaut [85 391 243 189] put
dup /Umacron [85 64 -649 30] put
dup /Uogonek [85 250 0 178] put
dup /uring [117 176 0 31] put
dup /uhungarumlaut [117 200 0 189] put
dup /umacron [117 176 0 30] put
dup /uogonek [117 176 0 178] put
dup /Zacute [90 254 243 180] put
dup /Zdotaccent [90 260 265 255] put
dup /zacute [122 118 0 180] put
dup /zdotaccent [122 93 0 255] put
makeComposite
%%EndResource
%%BeginResource: font NewCenturySchlbk-Italic-Ogonki
/NewCenturySchlbk-Italic /NewCenturySchlbk-Italic-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 246 256 27] put
dup /Aring [65 216 246 31] put
dup /Atilde [65 231 256 29] put
dup /Ecircumflex [69 255 256 28] put
dup /Egrave [69 255 256 27] put
dup /Idieresis [73 97 256 168] put
dup /Igrave [73 97 256 27] put
dup /Ntilde [78 301 256 29] put
dup /Ograve [79 283 256 27] put
dup /Otilde [79 283 256 29] put
dup /Ucircumflex [85 301 256 28] put
dup /Ugrave [85 301 256 27] put
dup /Ydieresis [89 236 256 168] put
dup /agrave [97 121 0 27] put
dup /aring [97 121 0 31] put
dup /atilde [97 121 0 29] put
dup /ecircumflex [101 56 0 28] put
dup /egrave [101 56 0 27] put
dup /idieresis [136 0 0 168] put
dup /igrave [136 0 0 27] put
dup /ntilde [110 139 0 29] put
dup /ograve [111 84 0 27] put
dup /otilde [111 84 0 29] put
dup /ucircumflex [117 139 0 28] put
dup /ugrave [117 139 0 27] put
dup /ydieresis [121 84 0 168] put
dup /Abreve [65 264 276 162] put
dup /Aogonek [65 393 0 178] put
dup /abreve [97 120 0 162] put
dup /aogonek [97 253 0 178] put
dup /Cacute [67 269 263 180] put
dup /Ccaron [67 336 263 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 75 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 297 263 183] put
dup /dcaron [100 565 74 39] put
dup /dbar [100 382 375 173] put
dup /Ecaron [69 269 263 183] put
dup /Edotaccent [69 261 237 255] put
dup /Eogonek [69 194 0 178] put
dup /ecaron [101 55 0 183] put
dup /edotaccent [101 55 0 255] put
dup /eogonek [101 55 0 178] put
dup /Gbreve [71 297 263 162] put
dup /gbreve [103 102 0 162] put
dup /Iogonek [73 37 0 178] put
dup /iogonek [105 0 0 178] put
dup /Lcaron [76 415 57 39] put
dup /Lacute [76 242 263 180] put
dup /lcaron [108 272 74 39] put
dup /lacute [108 97 263 180] put
dup /Nacute [78 358 263 180] put
dup /Ncaron [78 316 263 183] put
dup /nacute [110 161 0 180] put
dup /ncaron [110 139 0 183] put
dup /Ohungarumlaut [79 364 263 189] put
dup /ohungarumlaut [111 127 0 189] put
dup /Rcaron [82 279 263 183] put
dup /Racute [82 321 263 180] put
dup /rcaron [114 55 0 183] put
dup /racute [114 77 0 180] put
dup /Sacute [83 242 263 180] put
dup /Scedilla [83 167 0 184] put
dup /sacute [115 55 0 180] put
dup /scedilla [115 55 0 184] put
dup /Tcedilla [84 245 0 184] put
dup /Tcaron [84 251 263 183] put
dup /tcaron [116 308 0 39] put
dup /tcedilla [116 100 0 184] put
dup /Uring [85 310 241 31] put
dup /Uhungarumlaut [85 383 263 189] put
dup /Umacron [85 67 -610 30] put
dup /Uogonek [85 241 0 178] put
dup /uring [117 139 0 31] put
dup /uhungarumlaut [117 159 0 189] put
dup /umacron [117 139 0 30] put
dup /uogonek [117 139 0 178] put
dup /Zacute [90 242 263 180] put
dup /Zdotaccent [90 255 307 255] put
dup /zacute [122 87 0 180] put
dup /zdotaccent [122 65 0 255] put
makeComposite
%%EndResource
%%BeginResource: font NewCenturySchlbk-Roman-Ogonki
/NewCenturySchlbk-Roman /NewCenturySchlbk-Roman-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 195 238 27] put
dup /Aring [65 195 243 31] put
dup /Atilde [65 195 238 29] put
dup /Ecircumflex [69 195 238 28] put
dup /Egrave [69 195 238 27] put
dup /Idieresis [73 37 238 168] put
dup /Igrave [73 37 238 27] put
dup /Ntilde [78 241 238 29] put
dup /Ograve [79 223 238 27] put
dup /Otilde [79 223 238 29] put
dup /Ucircumflex [85 241 238 28] put
dup /Ugrave [85 241 238 27] put
dup /Ydieresis [89 186 238 168] put
dup /agrave [97 112 0 27] put
dup /aring [97 112 10 31] put
dup /atilde [97 112 0 29] put
dup /ecircumflex [101 84 0 28] put
dup /egrave [101 84 0 27] put
dup /idieresis [136 -9 0 168] put
dup /igrave [136 -9 0 27] put
dup /ntilde [110 139 0 29] put
dup /ograve [111 84 0 27] put
dup /otilde [111 84 0 29] put
dup /ucircumflex [117 139 0 28] put
dup /ugrave [117 139 0 27] put
dup /ydieresis [121 102 0 168] put
dup /Abreve [65 194 267 162] put
dup /Aogonek [65 402 0 178] put
dup /abreve [97 111 0 162] put
dup /aogonek [97 244 0 178] put
dup /Cacute [67 194 253 180] put
dup /Ccaron [67 256 253 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 75 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 222 253 183] put
dup /dcaron [100 542 74 39] put
dup /dbar [100 269 372 173] put
dup /Ecaron [69 194 253 183] put
dup /Edotaccent [69 194 238 255] put
dup /Eogonek [69 194 0 178] put
dup /ecaron [101 83 0 183] put
dup /edotaccent [101 83 0 255] put
dup /eogonek [101 83 0 178] put
dup /Gbreve [71 222 253 162] put
dup /gbreve [103 102 0 162] put
dup /Iogonek [73 37 0 178] put
dup /iogonek [105 -9 0 178] put
dup /Lcaron [76 359 57 39] put
dup /Lacute [76 167 253 180] put
dup /lcaron [108 276 74 39] put
dup /lacute [108 14 253 180] put
dup /Nacute [78 284 253 180] put
dup /Ncaron [78 241 253 183] put
dup /nacute [110 162 0 180] put
dup /ncaron [110 139 0 183] put
dup /Ohungarumlaut [79 284 253 189] put
dup /ohungarumlaut [111 127 0 189] put
dup /Rcaron [82 194 253 183] put
dup /Racute [82 237 253 180] put
dup /rcaron [114 55 0 183] put
dup /racute [114 78 0 180] put
dup /Sacute [83 148 253 180] put
dup /Scedilla [83 148 0 184] put
dup /sacute [115 65 0 180] put
dup /scedilla [115 65 0 184] put
dup /Tcedilla [84 230 0 184] put
dup /Tcaron [84 167 253 183] put
dup /tcaron [116 361 0 39] put
dup /tcedilla [116 134 0 184] put
dup /Uring [85 241 226 31] put
dup /Uhungarumlaut [85 303 253 189] put
dup /Umacron [85 241 -623 30] put
dup /Uogonek [85 241 0 178] put
dup /uring [117 139 0 31] put
dup /uhungarumlaut [117 159 0 189] put
dup /umacron [117 139 0 30] put
dup /uogonek [117 139 0 178] put
dup /Zacute [90 139 253 180] put
dup /Zdotaccent [90 139 303 255] put
dup /zacute [122 97 0 180] put
dup /zdotaccent [122 74 0 255] put
makeComposite
%%EndResource
%
% -------------------------------- Palatino composite ISO 8859-2 characters
%
%%BeginResource: font Palatino-Bold-Ogonki
/Palatino-Bold /Palatino-Bold-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 215 224 27] put
dup /Aring [65 223 224 31] put
dup /Atilde [65 223 224 29] put
dup /Ecircumflex [69 139 224 28] put
dup /Egrave [69 139 224 27] put
dup /Idieresis [73 28 224 168] put
dup /Igrave [73 28 224 27] put
dup /Ntilde [78 250 224 29] put
dup /Ograve [79 250 224 27] put
dup /Otilde [79 250 224 29] put
dup /Ucircumflex [85 235 224 28] put
dup /Ugrave [85 223 224 27] put
dup /Ydieresis [89 199 224 168] put
dup /agrave [97 84 20 27] put
dup /aring [97 84 0 31] put
dup /atilde [97 84 12 29] put
dup /ecircumflex [101 96 20 28] put
dup /egrave [101 84 20 27] put
dup /idieresis [136 0 20 168] put
dup /igrave [136 0 20 27] put
dup /ntilde [110 139 12 29] put
dup /ograve [111 112 20 27] put
dup /otilde [111 112 12 29] put
dup /ucircumflex [117 139 20 28] put
dup /ugrave [117 131 20 27] put
dup /ydieresis [121 124 20 168] put
dup /Abreve [65 222 253 162] put
dup /Aogonek [65 462 0 178] put
dup /abreve [97 83 0 162] put
dup /aogonek [97 236 0 178] put
dup /Cacute [67 194 231 180] put
dup /Ccaron [67 259 227 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 74 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 250 227 183] put
dup /dcaron [100 570 97 39] put
dup /dbar [100 320 329 173] put
dup /Ecaron [69 139 227 183] put
dup /Edotaccent [69 139 200 255] put
dup /Eogonek [69 139 0 178] put
dup /ecaron [101 83 0 183] put
dup /edotaccent [101 83 0 255] put
dup /eogonek [101 83 0 178] put
dup /Gbreve [71 250 231 162] put
dup /gbreve [103 111 0 162] put
dup /Iogonek [73 28 0 178] put
dup /iogonek [105 0 0 178] put
dup /Lcaron [76 343 54 39] put
dup /Lacute [76 139 231 180] put
dup /lcaron [108 289 97 39] put
dup /lacute [108 24 231 180] put
dup /Nacute [78 295 231 180] put
dup /Ncaron [78 250 227 183] put
dup /nacute [110 163 0 180] put
dup /ncaron [110 139 0 183] put
dup /Ohungarumlaut [79 315 231 189] put
dup /ohungarumlaut [111 153 0 189] put
dup /Rcaron [82 194 227 183] put
dup /Racute [82 239 231 180] put
dup /rcaron [114 28 0 183] put
dup /racute [114 52 0 180] put
dup /Sacute [83 139 231 180] put
dup /Scedilla [83 139 0 184] put
dup /sacute [115 55 0 180] put
dup /scedilla [115 55 0 184] put
dup /Tcedilla [84 230 0 184] put
dup /Tcaron [84 167 227 183] put
dup /tcaron [116 317 0 39] put
dup /tcedilla [116 91 0 184] put
dup /Uring [85 222 212 31] put
dup /Uhungarumlaut [85 287 231 189] put
dup /Umacron [85 222 -609 30] put
dup /Uogonek [85 222 0 178] put
dup /uring [117 139 0 31] put
dup /uhungarumlaut [117 158 0 189] put
dup /umacron [117 139 0 30] put
dup /uogonek [117 139 0 178] put
dup /Zacute [90 167 231 180] put
dup /Zdotaccent [90 167 241 255] put
dup /zacute [122 107 0 180] put
dup /zdotaccent [122 83 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Palatino-BoldItalic-Ogonki
/Palatino-BoldItalic /Palatino-BoldItalic-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 195 212 27] put
dup /Aring [65 83 212 31] put
dup /Atilde [65 195 212 29] put
dup /Ecircumflex [69 139 212 28] put
dup /Egrave [69 139 212 27] put
dup /Idieresis [73 28 212 168] put
dup /Igrave [73 28 212 27] put
dup /Ntilde [78 223 212 29] put
dup /Ograve [79 250 212 27] put
dup /Otilde [79 250 212 29] put
dup /Ucircumflex [85 223 212 28] put
dup /Ugrave [85 211 212 27] put
dup /Ydieresis [89 139 212 168] put
dup /agrave [97 112 20 27] put
dup /aring [97 0 0 31] put
dup /atilde [97 112 12 29] put
dup /ecircumflex [101 56 20 28] put
dup /egrave [101 56 20 27] put
dup /idieresis [136 0 20 168] put
dup /igrave [136 0 20 27] put
dup /ntilde [110 112 12 29] put
dup /ograve [111 112 20 27] put
dup /otilde [111 112 12 29] put
dup /ucircumflex [117 100 20 28] put
dup /ugrave [117 112 20 27] put
dup /ydieresis [121 112 20 168] put
dup /Abreve [65 235 238 162] put
dup /Aogonek [65 425 0 178] put
dup /abreve [97 111 0 162] put
dup /aogonek [97 258 0 178] put
dup /Cacute [67 214 219 180] put
dup /Ccaron [67 279 227 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 75 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 262 227 183] put
dup /dcaron [100 497 79 39] put
dup /dbar [100 337 339 173] put
dup /Ecaron [69 179 227 183] put
dup /Edotaccent [69 174 200 255] put
dup /Eogonek [69 139 0 178] put
dup /ecaron [101 55 0 183] put
dup /edotaccent [101 55 0 255] put
dup /eogonek [101 55 0 178] put
dup /Gbreve [71 260 219 162] put
dup /gbreve [103 83 0 162] put
dup /Iogonek [73 28 0 178] put
dup /iogonek [105 0 0 178] put
dup /Lcaron [76 359 29 39] put
dup /Lacute [76 177 219 180] put
dup /lcaron [108 265 79 39] put
dup /lacute [108 62 219 180] put
dup /Nacute [78 305 219 180] put
dup /Ncaron [78 262 227 183] put
dup /nacute [110 135 0 180] put
dup /ncaron [110 111 0 183] put
dup /Ohungarumlaut [79 351 219 189] put
dup /ohungarumlaut [111 155 0 189] put
dup /Rcaron [82 234 227 183] put
dup /Racute [82 277 219 180] put
dup /rcaron [114 28 0 183] put
dup /racute [114 52 0 180] put
dup /Sacute [83 149 219 180] put
dup /Scedilla [83 111 0 184] put
dup /sacute [115 55 0 180] put
dup /scedilla [115 55 0 184] put
dup /Tcedilla [84 201 0 184] put
dup /Tcaron [84 179 227 183] put
dup /tcaron [116 356 0 39] put
dup /tcedilla [116 138 0 184] put
dup /Uring [85 145 197 31] put
dup /Uhungarumlaut [85 323 219 189] put
dup /Umacron [85 115 -608 30] put
dup /Uogonek [85 222 0 178] put
dup /uring [117 0 0 31] put
dup /uhungarumlaut [117 131 0 189] put
dup /umacron [117 111 0 30] put
dup /uogonek [117 111 0 178] put
dup /Zacute [90 205 219 180] put
dup /Zdotaccent [90 209 243 255] put
dup /zacute [122 107 0 180] put
dup /zdotaccent [122 83 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Palatino-Italic-Ogonki
/Palatino-Italic /Palatino-Italic-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 235 210 27] put
dup /Aring [65 235 210 31] put
dup /Atilde [65 255 228 29] put
dup /Ecircumflex [69 179 210 28] put
dup /Egrave [69 167 210 27] put
dup /Idieresis [73 40 210 168] put
dup /Igrave [73 28 210 27] put
dup /Ntilde [78 263 228 29] put
dup /Ograve [79 251 210 27] put
dup /Otilde [79 263 228 29] put
dup /Ucircumflex [85 255 210 28] put
dup /Ugrave [85 235 210 27] put
dup /Ydieresis [89 187 210 168] put
dup /agrave [97 44 20 27] put
dup /aring [97 36 20 31] put
dup /atilde [97 56 12 29] put
dup /ecircumflex [101 48 20 28] put
dup /egrave [101 16 20 27] put
dup /idieresis [136 -27 20 168] put
dup /igrave [136 -39 20 27] put
dup /ntilde [110 112 12 29] put
dup /ograve [111 36 20 27] put
dup /otilde [111 56 12 29] put
dup /ucircumflex [117 112 20 28] put
dup /ugrave [117 100 20 27] put
dup /ydieresis [121 84 20 168] put
dup /Abreve [65 236 240 162] put
dup /Aogonek [65 371 0 178] put
dup /abreve [97 55 0 162] put
dup /aogonek [97 168 0 178] put
dup /Cacute [67 207 230 180] put
dup /Ccaron [67 269 238 183] put
dup /cacute [99 37 0 180] put
dup /ccaron [99 55 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 263 238 183] put
dup /dcaron [100 423 73 39] put
dup /dbar [100 318 364 173] put
dup /Ecaron [69 180 238 183] put
dup /Edotaccent [69 176 211 255] put
dup /Eogonek [69 139 0 178] put
dup /ecaron [101 28 0 183] put
dup /edotaccent [101 28 0 255] put
dup /eogonek [101 28 0 178] put
dup /Gbreve [71 234 230 162] put
dup /gbreve [103 83 0 162] put
dup /Iogonek [73 0 0 178] put
dup /iogonek [105 -27 0 178] put
dup /Lcaron [76 294 28 39] put
dup /Lacute [76 151 230 180] put
dup /lcaron [108 191 73 39] put
dup /lacute [108 35 230 180] put
dup /Nacute [78 305 230 180] put
dup /Ncaron [78 263 238 183] put
dup /nacute [110 133 0 180] put
dup /ncaron [110 111 0 183] put
dup /Ohungarumlaut [79 315 187 189] put
dup /ohungarumlaut [111 95 0 189] put
dup /Rcaron [82 208 238 183] put
dup /Racute [82 250 230 180] put
dup /rcaron [114 28 0 183] put
dup /racute [114 50 0 180] put
dup /Sacute [83 151 230 180] put
dup /Scedilla [83 111 0 184] put
dup /sacute [115 28 0 180] put
dup /scedilla [115 28 0 184] put
dup /Tcedilla [84 197 0 184] put
dup /Tcaron [84 180 238 183] put
dup /tcaron [116 250 0 39] put
dup /tcedilla [116 81 0 184] put
dup /Uring [85 258 209 31] put
dup /Uhungarumlaut [85 315 187 189] put
dup /Umacron [85 119 -589 30] put
dup /Uogonek [85 222 0 178] put
dup /uring [117 111 0 31] put
dup /uhungarumlaut [117 129 0 189] put
dup /umacron [117 111 0 30] put
dup /uogonek [117 111 0 178] put
dup /Zacute [90 207 230 180] put
dup /Zdotaccent [90 214 272 255] put
dup /zacute [122 77 0 180] put
dup /zdotaccent [122 55 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Palatino-Roman-Ogonki
/Palatino-Roman /Palatino-Roman-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 215 231 27] put
dup /Aring [65 223 231 31] put
dup /Atilde [65 223 231 29] put
dup /Ecircumflex [69 139 231 28] put
dup /Egrave [69 139 231 27] put
dup /Idieresis [73 2 231 168] put
dup /Igrave [73 2 231 27] put
dup /Ntilde [78 249 231 29] put
dup /Ograve [79 227 231 27] put
dup /Otilde [79 227 243 29] put
dup /Ucircumflex [85 247 231 28] put
dup /Ugrave [85 223 231 27] put
dup /Ydieresis [89 191 231 168] put
dup /agrave [97 60 20 27] put
dup /aring [97 72 20 31] put
dup /atilde [97 72 12 29] put
dup /ecircumflex [101 85 20 28] put
dup /egrave [101 73 20 27] put
dup /idieresis [136 -23 20 168] put
dup /igrave [136 -23 20 27] put
dup /ntilde [110 113 12 29] put
dup /ograve [111 95 20 27] put
dup /otilde [111 107 12 29] put
dup /ucircumflex [117 135 20 28] put
dup /ugrave [117 111 20 27] put
dup /ydieresis [121 112 20 168] put
dup /Abreve [65 222 255 162] put
dup /Aogonek [65 430 0 178] put
dup /abreve [97 83 0 162] put
dup /aogonek [97 220 0 178] put
dup /Cacute [67 188 242 180] put
dup /Ccaron [67 253 238 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 74 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 220 238 183] put
dup /dcaron [100 553 90 39] put
dup /dbar [100 316 352 173] put
dup /Ecaron [69 139 238 183] put
dup /Edotaccent [69 180 211 255] put
dup /Eogonek [69 149 0 178] put
dup /ecaron [101 73 0 183] put
dup /edotaccent [101 114 0 255] put
dup /eogonek [101 83 0 178] put
dup /Gbreve [71 215 242 162] put
dup /gbreve [103 111 0 162] put
dup /Iogonek [73 12 0 178] put
dup /iogonek [105 -11 0 178] put
dup /Lcaron [76 289 52 39] put
dup /Lacute [76 139 242 180] put
dup /lcaron [108 245 90 39] put
dup /lacute [108 1 242 180] put
dup /Nacute [78 292 242 180] put
dup /Ncaron [78 249 238 183] put
dup /nacute [110 146 0 180] put
dup /ncaron [110 124 0 183] put
dup /Ohungarumlaut [79 268 232 189] put
dup /ohungarumlaut [111 125 0 189] put
dup /Rcaron [82 167 238 183] put
dup /Racute [82 210 242 180] put
dup /rcaron [114 31 0 183] put
dup /racute [114 53 0 180] put
dup /Sacute [83 96 242 180] put
dup /Scedilla [83 96 0 184] put
dup /sacute [115 45 0 180] put
dup /scedilla [115 45 0 184] put
dup /Tcedilla [84 198 0 184] put
dup /Tcaron [84 140 238 183] put
dup /tcaron [116 293 0 39] put
dup /tcedilla [116 86 0 184] put
dup /Uring [85 222 219 31] put
dup /Uhungarumlaut [85 264 232 189] put
dup /Umacron [85 222 -591 30] put
dup /Uogonek [85 232 0 178] put
dup /uring [117 135 0 31] put
dup /uhungarumlaut [117 130 0 189] put
dup /umacron [117 135 0 30] put
dup /uogonek [117 145 0 178] put
dup /Zacute [90 167 242 180] put
dup /Zdotaccent [90 208 278 255] put
dup /zacute [122 105 0 180] put
dup /zdotaccent [122 125 0 255] put
makeComposite
%%EndResource
%
% ----------------------------------- Times composite ISO 8859-2 characters
%
%%BeginResource: font Times-Bold-Ogonki
/Times-Bold /Times-Bold-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Ydieresis [89 194 219 168] put
dup /ydieresis [121 83 0 168] put
dup /Ucircumflex [85 221 219 28] put
dup /Ugrave [85 221 219 27] put
dup /ucircumflex [117 104 0 28] put
dup /ugrave [117 104 0 27] put
dup /Idieresis [73 28 219 168] put
dup /Igrave [73 28 219 27] put
dup /idieresis [136 -34 0 168] put
dup /igrave [136 -34 0 27] put
dup /Ecircumflex [69 174 219 28] put
dup /Egrave [69 174 219 27] put
dup /ecircumflex [101 61 0 28] put
dup /egrave [101 61 0 27] put
dup /Agrave [65 187 219 27] put
dup /agrave [97 76 0 27] put
dup /Ograve [79 222 219 27] put
dup /ograve [111 83 0 27] put
dup /Atilde [65 187 219 29] put
dup /atilde [97 76 0 29] put
dup /Ntilde [78 194 219 29] put
dup /ntilde [110 111 0 29] put
dup /Otilde [79 222 219 29] put
dup /otilde [111 83 0 29] put
dup /Aring [65 187 219 31] put
dup /aring [97 76 0 31] put
dup /Abreve [65 194 240 162] put
dup /Aogonek [65 437 0 178] put
dup /abreve [97 83 0 162] put
dup /aogonek [97 238 0 178] put
dup /Cacute [67 194 212 180] put
dup /Ccaron [67 257 215 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 75 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 194 215 183] put
dup /dcaron [100 464 57 39] put
dup /dbar [100 252 305 173] put
dup /Ecaron [69 167 215 183] put
dup /Edotaccent [69 167 220 255] put
dup /Eogonek [69 167 0 178] put
dup /ecaron [101 55 0 183] put
dup /edotaccent [101 55 0 255] put
dup /eogonek [101 55 0 178] put
dup /Gbreve [71 222 206 162] put
dup /gbreve [103 83 0 162] put
dup /Iogonek [73 28 0 178] put
dup /iogonek [105 -27 0 178] put
dup /Lcaron [76 307 68 39] put
dup /Lacute [76 167 212 180] put
dup /lcaron [108 188 57 39] put
dup /lacute [108 -5 212 180] put
dup /Nacute [78 235 212 180] put
dup /Ncaron [78 194 215 183] put
dup /nacute [110 133 0 180] put
dup /ncaron [110 111 0 183] put
dup /Ohungarumlaut [79 285 154 189] put
dup /ohungarumlaut [111 127 0 189] put
dup /Rcaron [82 194 215 183] put
dup /Racute [82 235 212 180] put
dup /rcaron [114 55 0 183] put
dup /racute [114 77 0 180] put
dup /Sacute [83 111 212 180] put
dup /Scedilla [83 111 0 184] put
dup /sacute [115 28 0 180] put
dup /scedilla [115 28 0 184] put
dup /Tcedilla [84 227 0 184] put
dup /Tcaron [84 167 215 183] put
dup /tcaron [116 261 0 39] put
dup /tcedilla [116 89 0 184] put
dup /Uring [85 194 159 31] put
dup /Uhungarumlaut [85 257 154 189] put
dup /Umacron [85 194 -600 30] put
dup /Uogonek [85 194 0 178] put
dup /uring [117 111 0 31] put
dup /uhungarumlaut [117 131 0 189] put
dup /umacron [117 111 0 30] put
dup /uogonek [117 111 0 178] put
dup /Zacute [90 167 212 180] put
dup /Zdotaccent [90 167 280 255] put
dup /zacute [122 77 0 180] put
dup /zdotaccent [122 55 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Times-BoldItalic-Ogonki
/Times-BoldItalic /Times-BoldItalic-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Ydieresis [89 139 204 168] put
dup /ydieresis [121 55 0 168] put
dup /Ucircumflex [85 194 204 28] put
dup /Ugrave [85 194 204 27] put
dup /ucircumflex [117 111 0 28] put
dup /ugrave [117 111 0 27] put
dup /Idieresis [73 28 204 168] put
dup /Igrave [73 28 204 27] put
dup /idieresis [136 -27 0 168] put
dup /igrave [136 -27 0 27] put
dup /Ecircumflex [69 167 204 28] put
dup /Egrave [69 167 204 27] put
dup /ecircumflex [101 55 0 28] put
dup /egrave [101 55 0 27] put
dup /Agrave [65 167 204 27] put
dup /agrave [97 83 0 27] put
dup /Ograve [79 194 204 27] put
dup /ograve [111 83 0 27] put
dup /Atilde [65 167 204 29] put
dup /atilde [97 83 0 29] put
dup /Ntilde [78 194 204 29] put
dup /ntilde [110 111 0 29] put
dup /Otilde [79 194 204 29] put
dup /otilde [111 83 0 29] put
dup /Aring [65 167 204 31] put
dup /aring [97 83 0 31] put
dup /Abreve [65 227 224 162] put
dup /Aogonek [65 423 0 178] put
dup /abreve [97 83 0 162] put
dup /aogonek [97 247 0 178] put
dup /Cacute [67 221 205 180] put
dup /Ccaron [67 285 205 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 75 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 248 205 183] put
dup /dcaron [100 481 75 39] put
dup /dbar [100 328 318 173] put
dup /Ecaron [69 221 205 183] put
dup /Edotaccent [69 219 197 255] put
dup /Eogonek [69 167 0 178] put
dup /ecaron [101 55 0 183] put
dup /edotaccent [101 55 0 255] put
dup /eogonek [101 55 0 178] put
dup /Gbreve [71 248 205 162] put
dup /gbreve [103 83 0 162] put
dup /Iogonek [73 28 0 178] put
dup /iogonek [105 -27 0 178] put
dup /Lcaron [76 352 53 39] put
dup /Lacute [76 193 205 180] put
dup /lcaron [108 251 75 39] put
dup /lacute [108 51 205 180] put
dup /Nacute [78 293 205 180] put
dup /Ncaron [78 248 205 183] put
dup /nacute [110 135 0 180] put
dup /ncaron [110 111 0 183] put
dup /Ohungarumlaut [79 296 145 189] put
dup /ohungarumlaut [111 127 0 189] put
dup /Rcaron [82 221 205 183] put
dup /Racute [82 266 205 180] put
dup /rcaron [114 28 0 183] put
dup /racute [114 52 0 180] put
dup /Sacute [83 165 205 180] put
dup /Scedilla [83 111 0 184] put
dup /sacute [115 28 0 180] put
dup /scedilla [115 28 0 184] put
dup /Tcedilla [84 198 0 184] put
dup /Tcaron [84 193 205 183] put
dup /tcaron [116 244 0 39] put
dup /tcedilla [116 60 0 184] put
dup /Uring [85 250 212 31] put
dup /Uhungarumlaut [85 296 145 189] put
dup /Umacron [85 29 -616 30] put
dup /Uogonek [85 194 0 178] put
dup /uring [117 111 0 31] put
dup /uhungarumlaut [117 131 0 189] put
dup /umacron [117 111 0 30] put
dup /uogonek [117 111 0 178] put
dup /Zacute [90 193 205 180] put
dup /Zdotaccent [90 203 240 255] put
dup /zacute [122 52 0 180] put
dup /zdotaccent [122 28 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Times-Italic-Ogonki
/Times-Italic /Times-Italic-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 149 212 27] put
dup /Aring [65 129 192 31] put
dup /Atilde [65 139 212 29] put
dup /Ecircumflex [69 169 212 28] put
dup /Egrave [69 149 212 27] put
dup /Idieresis [73 30 212 168] put
dup /Igrave [73 10 212 27] put
dup /Ntilde [78 177 212 29] put
dup /Ograve [79 205 212 27] put
dup /Otilde [79 215 212 29] put
dup /Ucircumflex [85 215 212 28] put
dup /Ugrave [85 215 212 27] put
dup /Ydieresis [89 142 212 168] put
dup /agrave [97 84 0 27] put
dup /aring [97 84 0 31] put
dup /atilde [97 84 0 29] put
dup /ecircumflex [101 56 0 28] put
dup /egrave [101 56 0 27] put
dup /idieresis [136 -52 0 168] put
dup /igrave [136 -27 0 27] put
dup /ntilde [110 49 0 29] put
dup /ograve [111 84 0 27] put
dup /otilde [111 69 0 29] put
dup /ucircumflex [117 74 0 28] put
dup /ugrave [117 84 0 27] put
dup /ydieresis [121 36 0 168] put
dup /Abreve [65 199 226 162] put
dup /Aogonek [65 385 0 178] put
dup /abreve [97 83 0 162] put
dup /aogonek [97 240 0 178] put
dup /Cacute [67 223 212 180] put
dup /Ccaron [67 286 214 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 75 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 251 214 183] put
dup /dcaron [100 390 85 39] put
dup /dbar [100 315 346 173] put
dup /Ecaron [69 196 214 183] put
dup /Edotaccent [69 192 198 255] put
dup /Eogonek [69 139 0 178] put
dup /ecaron [101 55 0 183] put
dup /edotaccent [101 55 0 255] put
dup /eogonek [101 55 0 178] put
dup /Gbreve [71 251 214 162] put
dup /gbreve [103 83 0 162] put
dup /Iogonek [73 0 0 178] put
dup /iogonek [105 -27 0 178] put
dup /Lcaron [76 247 52 39] put
dup /Lacute [76 167 212 180] put
dup /lcaron [108 142 85 39] put
dup /lacute [108 51 212 180] put
dup /Nacute [78 265 212 180] put
dup /Ncaron [78 224 214 183] put
dup /nacute [110 105 0 180] put
dup /ncaron [110 83 0 183] put
dup /Ohungarumlaut [79 312 212 189] put
dup /ohungarumlaut [111 127 0 189] put
dup /Rcaron [82 196 214 183] put
dup /Racute [82 237 212 180] put
dup /rcaron [114 28 0 183] put
dup /racute [114 50 0 180] put
dup /Sacute [83 139 212 180] put
dup /Scedilla [83 83 0 184] put
dup /sacute [115 28 0 180] put
dup /scedilla [115 28 0 184] put
dup /Tcedilla [84 168 0 184] put
dup /Tcaron [84 168 214 183] put
dup /tcaron [116 159 0 39] put
dup /tcedilla [116 51 0 184] put
dup /Uring [85 243 184 31] put
dup /Uhungarumlaut [85 312 212 189] put
dup /Umacron [85 38 -583 30] put
dup /Uogonek [85 194 0 178] put
dup /uring [117 83 0 31] put
dup /uhungarumlaut [117 103 0 189] put
dup /umacron [117 83 0 30] put
dup /uogonek [117 83 0 178] put
dup /Zacute [90 167 212 180] put
dup /Zdotaccent [90 183 269 255] put
dup /zacute [122 50 0 180] put
dup /zdotaccent [122 28 0 255] put
makeComposite
%%EndResource
%%BeginResource: font Times-Roman-Ogonki
/Times-Roman /Times-Roman-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 195 212 27] put
dup /Aring [65 185 187 31] put
dup /Atilde [65 195 212 29] put
dup /Ecircumflex [69 139 212 28] put
dup /Egrave [69 139 212 27] put
dup /Idieresis [73 0 212 168] put
dup /Igrave [73 0 212 27] put
dup /Ntilde [78 195 212 29] put
dup /Ograve [79 195 212 27] put
dup /Otilde [79 195 212 29] put
dup /Ucircumflex [85 195 212 28] put
dup /Ugrave [85 195 212 27] put
dup /Ydieresis [89 195 212 168] put
dup /agrave [97 56 0 27] put
dup /aring [97 56 0 31] put
dup /atilde [97 56 0 29] put
dup /ecircumflex [101 56 0 28] put
dup /egrave [101 56 0 27] put
dup /idieresis [136 -27 0 168] put
dup /igrave [136 -27 0 27] put
dup /ntilde [110 84 0 29] put
dup /ograve [111 84 0 27] put
dup /otilde [111 84 0 29] put
dup /ucircumflex [117 84 0 28] put
dup /ugrave [117 84 0 27] put
dup /ydieresis [121 84 0 168] put
dup /Abreve [65 194 223 162] put
dup /Aogonek [65 401 0 178] put
dup /abreve [97 55 0 162] put
dup /aogonek [97 187 0 178] put
dup /Cacute [67 167 209 180] put
dup /Ccaron [67 228 209 183] put
dup /cacute [99 55 0 180] put
dup /ccaron [99 74 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 194 209 183] put
dup /dcaron [100 426 75 39] put
dup /dbar [100 231 344 173] put
dup /Ecaron [69 139 209 183] put
dup /Edotaccent [69 139 193 255] put
dup /Eogonek [69 139 0 178] put
dup /ecaron [101 55 0 183] put
dup /edotaccent [101 55 0 255] put
dup /eogonek [101 55 0 178] put
dup /Gbreve [71 194 209 162] put
dup /gbreve [103 83 0 162] put
dup /Iogonek [73 0 0 178] put
dup /iogonek [105 -27 0 178] put
dup /Lcaron [76 250 52 39] put
dup /Lacute [76 139 209 180] put
dup /lcaron [108 192 75 39] put
dup /lacute [108 -5 209 180] put
dup /Nacute [78 237 209 180] put
dup /Ncaron [78 194 209 183] put
dup /nacute [110 105 0 180] put
dup /ncaron [110 83 0 183] put
dup /Ohungarumlaut [79 255 209 189] put
dup /ohungarumlaut [111 125 0 189] put
dup /Rcaron [82 167 209 183] put
dup /Racute [82 210 209 180] put
dup /rcaron [114 0 0 183] put
dup /racute [114 22 0 180] put
dup /Sacute [83 111 209 180] put
dup /Scedilla [83 111 0 184] put
dup /sacute [115 28 0 180] put
dup /scedilla [115 28 0 184] put
dup /Tcedilla [84 197 0 184] put
dup /Tcaron [84 139 209 183] put
dup /tcaron [116 214 0 39] put
dup /tcedilla [116 53 0 184] put
dup /Uring [85 194 172 31] put
dup /Uhungarumlaut [85 255 209 189] put
dup /Umacron [85 194 -601 30] put
dup /Uogonek [85 194 0 178] put
dup /uring [117 83 0 31] put
dup /uhungarumlaut [117 102 0 189] put
dup /umacron [117 83 0 30] put
dup /uogonek [117 83 0 178] put
dup /Zacute [90 139 209 180] put
dup /Zdotaccent [90 139 260 255] put
dup /zacute [122 77 0 180] put
dup /zdotaccent [122 55 0 255] put
makeComposite
%%EndResource
%
% --------------------------- Zapf Chancery composite ISO 8859-2 characters
%
%%BeginResource: font ZapfChancery-MediumItalic-Ogonki
/ZapfChancery-MediumItalic /ZapfChancery-MediumItalic-Ogonki OgonkiEncoding StandardEncoding 82 dict
dup /Agrave [65 250 162 27] put
dup /Aring [65 260 172 31] put
dup /Atilde [65 180 152 29] put
dup /Ecircumflex [69 180 172 28] put
dup /Egrave [69 220 162 27] put
dup /Idieresis [73 50 152 168] put
dup /Igrave [73 100 162 27] put
dup /Ntilde [78 210 142 29] put
dup /Ograve [79 150 162 27] put
dup /Otilde [79 90 142 29] put
dup /Ucircumflex [85 260 172 28] put
dup /Ugrave [85 270 162 27] put
dup /Ydieresis [89 170 152 168] put
dup /agrave [97 80 0 27] put
dup /aring [97 60 0 31] put
dup /atilde [97 0 0 29] put
dup /ecircumflex [101 -10 0 28] put
dup /egrave [101 30 0 27] put
dup /idieresis [136 -100 0 168] put
dup /igrave [136 -40 0 27] put
dup /ntilde [110 10 0 29] put
dup /ograve [111 60 0 27] put
dup /otilde [111 -20 0 29] put
dup /ucircumflex [117 30 0 28] put
dup /ugrave [117 50 0 27] put
dup /ydieresis [121 0 0 168] put
dup /Abreve [65 134 178 162] put
dup /Aogonek [65 388 0 178] put
dup /abreve [97 -10 0 162] put
dup /aogonek [97 209 0 178] put
dup /Cacute [67 147 150 180] put
dup /Ccaron [67 181 150 183] put
dup /cacute [99 20 0 180] put
dup /ccaron [99 16 0 183] put
dup /Dbar [208 0 0 160] put
dup /Dcaron [68 217 150 183] put
dup /dcaron [100 500 175 39] put
dup /dbar [100 333 380 173] put
dup /Ecaron [69 177 150 183] put
dup /Edotaccent [69 229 120 255] put
dup /Eogonek [69 170 0 178] put
dup /ecaron [101 0 0 183] put
dup /edotaccent [101 60 0 255] put
dup /eogonek [101 30 0 178] put
dup /Gbreve [71 119 120 162] put
dup /gbreve [103 -20 0 162] put
dup /Iogonek [73 50 0 178] put
dup /iogonek [105 -20 0 178] put
dup /Lcaron [76 353 43 39] put
dup /Lacute [76 177 150 180] put
dup /lcaron [108 329 175 39] put
dup /lacute [108 23 150 180] put
dup /Nacute [78 267 150 180] put
dup /Ncaron [78 217 150 183] put
dup /nacute [110 96 0 180] put
dup /ncaron [110 60 0 183] put
dup /Ohungarumlaut [79 191 150 189] put
dup /ohungarumlaut [111 35 0 189] put
dup /Rcaron [82 167 150 183] put
dup /Racute [82 217 150 180] put
dup /rcaron [114 -20 0 183] put
dup /racute [114 16 0 180] put
dup /Sacute [83 117 150 180] put
dup /Scedilla [83 80 0 184] put
dup /sacute [115 10 0 180] put
dup /scedilla [115 10 0 184] put
dup /Tcedilla [84 168 0 184] put
dup /Tcaron [84 117 150 183] put
dup /tcaron [116 275 0 39] put
dup /tcedilla [116 106 0 184] put
dup /Uring [85 257 150 31] put
dup /Uhungarumlaut [85 261 150 189] put
dup /Umacron [85 6 -578 30] put
dup /Uogonek [85 230 0 178] put
dup /uring [117 80 0 31] put
dup /uhungarumlaut [117 46 0 189] put
dup /umacron [117 10 0 30] put
dup /uogonek [117 90 0 178] put
dup /Zacute [90 197 150 180] put
dup /Zdotaccent [90 249 199 255] put
dup /zacute [122 86 0 180] put
dup /zdotaccent [122 110 0 255] put
makeComposite
%%EndResource
%
% ------------------------------------------------ Recoded font definitions
%
/AvantGarde-Book-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/AvantGarde-Book-Ogonki newfont definefont pop
/AvantGarde-BookOblique-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/AvantGarde-BookOblique-Ogonki newfont definefont pop
/AvantGarde-Demi-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/AvantGarde-Demi-Ogonki newfont definefont pop
/AvantGarde-DemiOblique-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/AvantGarde-DemiOblique-Ogonki newfont definefont pop
/Bookman-Demi-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Bookman-Demi-Ogonki newfont definefont pop
/Bookman-DemiItalic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Bookman-DemiItalic-Ogonki newfont definefont pop
/Bookman-Light-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Bookman-Light-Ogonki newfont definefont pop
/Bookman-LightItalic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Bookman-LightItalic-Ogonki newfont definefont pop
/Courier-Bold-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Courier-Bold-Ogonki newfont definefont pop
/Courier-BoldOblique-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Courier-BoldOblique-Ogonki newfont definefont pop
/Courier-Oblique-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Courier-Oblique-Ogonki newfont definefont pop
/Courier-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Courier-Ogonki newfont definefont pop
/Helvetica-Bold-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Helvetica-Bold-Ogonki newfont definefont pop
/Helvetica-BoldOblique-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Helvetica-BoldOblique-Ogonki newfont definefont pop
/Helvetica-Narrow-Bold-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Helvetica-Narrow-Bold-Ogonki newfont definefont pop
/Helvetica-Narrow-BoldOblique-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Helvetica-Narrow-BoldOblique-Ogonki newfont definefont pop
/Helvetica-Narrow-Oblique-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Helvetica-Narrow-Oblique-Ogonki newfont definefont pop
/Helvetica-Narrow-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Helvetica-Narrow-Ogonki newfont definefont pop
/Helvetica-Oblique-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Helvetica-Oblique-Ogonki newfont definefont pop
/Helvetica-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Helvetica-Ogonki newfont definefont pop
/NewCenturySchlbk-Bold-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/NewCenturySchlbk-Bold-Ogonki newfont definefont pop
/NewCenturySchlbk-BoldItalic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/NewCenturySchlbk-BoldItalic-Ogonki newfont definefont pop
/NewCenturySchlbk-Italic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/NewCenturySchlbk-Italic-Ogonki newfont definefont pop
/NewCenturySchlbk-Roman-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/NewCenturySchlbk-Roman-Ogonki newfont definefont pop
/Palatino-Bold-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Palatino-Bold-Ogonki newfont definefont pop
/Palatino-BoldItalic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Palatino-BoldItalic-Ogonki newfont definefont pop
/Palatino-Italic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Palatino-Italic-Ogonki newfont definefont pop
/Palatino-Roman-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Palatino-Roman-Ogonki newfont definefont pop
/Times-Bold-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Times-Bold-Ogonki newfont definefont pop
/Times-BoldItalic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Times-BoldItalic-Ogonki newfont definefont pop
/Times-Italic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Times-Italic-Ogonki newfont definefont pop
/Times-Roman-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/Times-Roman-Ogonki newfont definefont pop
/ZapfChancery-MediumItalic-Ogonki findfont 
dup length 1 add dict dup /newfont exch def 
begin
  {1 index /FID ne
    {def}
    {pop pop} ifelse
  } bind forall
end
newfont /Encoding ISOLatin2Encoding put
/ZapfChancery-MediumItalic-Ogonki newfont definefont pop

%                                              ******************************
% -------------------------------------------- ISO Latin 2 prologue ends here
%                                              ******************************


/reencodeFontISO { %def
  dup
  length 12 add dict	% Make a new font (a new dict the same size
			% as the old one) with room for our new symbols.

  begin			% Make the new font the current dictionary.


    { 1 index /FID ne
      { def } { pop pop } ifelse
    } forall		% Copy each of the symbols from the old dictionary
			% to the new one except for the font ID.

    /Encoding ISOLatin2Encoding def	% Override the encoding with
					% the ISOLatin2 encoding.

    % Use the font's bounding box to determine the ascent, descent,
    % and overall height; don't forget that these values have to be
    % transformed using the font's matrix.

%          ^    (x2 y2)
%          |       |
%          |       v
%          |  +----+ - -
%          |  |    |   ^
%          |  |    |   | Ascent (usually > 0)
%          |  |    |   |
% (0 0) -> +--+----+-------->
%             |    |   |
%             |    |   v Descent (usually < 0)
% (x1 y1) --> +----+ - -

    FontBBox				% -- x1 y1 x2 y2
    FontMatrix transform /Ascent  exch def pop
    FontMatrix transform /Descent exch def pop
    /FontHeight Ascent Descent sub def	% use `sub' because descent < 0

    % Define these in case they're not in the FontInfo
    % (also, here they're easier to get to).
    /UnderlinePosition  Descent 0.70 mul def
    /OverlinePosition   Descent UnderlinePosition sub Ascent add def
    /StrikeoutPosition  Ascent 0.30 mul def
    /LineThickness      0  50 FontMatrix transform exch pop def
    /Xshadow            0  80 FontMatrix transform exch pop def
    /Yshadow            0 -90 FontMatrix transform exch pop def
    /SpaceBackground    Descent neg UnderlinePosition add def
    /XBox               Descent neg def
    /YBox               LineThickness 0.7 mul def

    currentdict		% Leave the new font on the stack
    end			% Stop using the font as the current dictionary.
    definefont		% Put the font into the font dictionary
    pop			% Discard the returned font.
} bind def
")

(defvar ps-print-prologue
  "
/DefFont {				% Font definition
  findfont exch scalefont reencodeFontISO
} def

/F {					% Font selection
  findfont
  dup /Ascent            get /Ascent            exch def
  dup /Descent           get /Descent           exch def
  dup /FontHeight        get /FontHeight        exch def
  dup /UnderlinePosition get /UnderlinePosition exch def
  dup /OverlinePosition  get /OverlinePosition  exch def
  dup /StrikeoutPosition get /StrikeoutPosition exch def
  dup /LineThickness     get /LineThickness     exch def
  dup /Xshadow           get /Xshadow           exch def
  dup /Yshadow           get /Yshadow           exch def
  dup /SpaceBackground   get /SpaceBackground   exch def
  dup /XBox              get /XBox              exch def
  dup /YBox              get /YBox              exch def
  setfont
} def

/FG /setrgbcolor load def

/bg false def
/BG {
  dup /bg exch def
  {mark 4 1 roll ]}
  {[ 1.0 1.0 1.0 ]}
  ifelse
  /bgcolor exch def
} def

%  B    width    C
%   +-----------+
%               | Ascent  (usually > 0)
% A +           +
%               | Descent (usually < 0)
%   +-----------+
%  E    width    D

/dobackground {				% width --
  currentpoint				% -- width x y
  gsave
    newpath
    moveto				% A (x y)
    0 Ascent rmoveto			% B
    dup 0 rlineto			% C
    0 Descent Ascent sub rlineto	% D
    neg 0 rlineto			% E
    closepath
    bgcolor aload pop setrgbcolor
    fill
  grestore
} def

/eolbg {				% dobackground until right margin
  PrintWidth				% -- x-eol
  currentpoint pop			% -- cur-x
  sub					% -- width until eol
  dobackground
} def

/PLN {PrintLineNumber {doLineNumber}if} def

/SL {					% Soft Linefeed
  bg { eolbg } if
  0  currentpoint exch pop LineHeight sub  moveto
} def

/HL {SL PLN} def			% Hard Linefeed

% Some debug
/dcp { currentpoint exch 40 string cvs print (, ) print = } def
/dp { print 2 copy  exch 40 string cvs print (, ) print = } def

/W {
  ( ) stringwidth	% Get the width of a space in the current font.
  pop			% Discard the Y component.
  mul			% Multiply the width of a space
			% by the number of spaces to plot
  bg { dup dobackground } if
  0 rmoveto
} def

/Effect 0 def
/EF {/Effect exch def} def

% stack:  string  |-  --
% effect: 1  - underline  2   - strikeout  4  - overline
%         8  - shadow     16  - box        32 - outline
/S {
  /xx currentpoint dup Descent add /yy exch def
  Ascent add /YY exch def def
  dup stringwidth pop xx add /XX exch def
  Effect 8 and 0 ne {
    /yy yy Yshadow add def
    /XX XX Xshadow add def
  } if
  bg {
    true
    Effect 16 and 0 ne
      {SpaceBackground doBox}
      {xx yy XX YY doRect}
    ifelse
  } if							% background
  Effect 16 and 0 ne {false 0 doBox}if			% box
  Effect 8  and 0 ne {dup doShadow}if			% shadow
  Effect 32 and 0 ne
    {true doOutline}					% outline
    {show}						% normal text
  ifelse
  Effect 1  and 0 ne {UnderlinePosition Hline}if	% underline
  Effect 2  and 0 ne {StrikeoutPosition Hline}if	% strikeout
  Effect 4  and 0 ne {OverlinePosition  Hline}if	% overline
} bind def

% stack:  position  |-  --
/Hline {
  currentpoint exch pop add dup
  gsave
  newpath
  xx exch moveto
  XX exch lineto
  closepath
  LineThickness setlinewidth stroke
  grestore
} bind def

% stack:  fill-or-not delta  |-  --
/doBox {
  /dd exch def
  xx XBox sub dd sub yy YBox sub dd sub
  XX XBox add dd add YY YBox add dd add
  doRect
} bind def

% stack:  fill-or-not lower-x lower-y upper-x upper-y  |-  --
/doRect {
  /rYY exch def
  /rXX exch def
  /ryy exch def
  /rxx exch def
  gsave
  newpath
  rXX rYY moveto
  rxx rYY lineto
  rxx ryy lineto
  rXX ryy lineto
  closepath
  % top of stack: fill-or-not
    {FillBgColor}
    {LineThickness setlinewidth stroke}
  ifelse
  grestore
} bind def

% stack:  string  |-  --
/doShadow {
  gsave
  Xshadow Yshadow rmoveto
  false doOutline
  grestore
} bind def

/st 1 string def

% stack:  string fill-or-not  |-  --
/doOutline {
  /-fillp- exch def
  /-ox- currentpoint /-oy- exch def def
  gsave
  LineThickness setlinewidth
  {
    st 0 3 -1 roll put
    st dup true charpath
    -fillp- {gsave FillBgColor grestore}if
    stroke stringwidth
    -oy- add /-oy- exch def
    -ox- add /-ox- exch def
    -ox- -oy- moveto
  } forall
  grestore
  -ox- -oy- moveto
} bind def

% stack:  --
/FillBgColor {bgcolor aload pop setrgbcolor fill} bind def

/L0 6 /Times-Italic DefFont

% stack:  --
/doLineNumber {
  /LineNumber where
  {
    pop
    currentfont
    gsave
    0.0 0.0 0.0 setrgbcolor
    /L0 findfont setfont
    LineNumber Lines ge
      {(end      )}
      {LineNumber 6 string cvs (      ) strcat}
    ifelse
    dup stringwidth pop neg 0 rmoveto
    show
    grestore
    setfont
    /LineNumber LineNumber 1 add def
  } if
} def

% stack: --
/printZebra {
  gsave
  0.985 setgray
  /double-zebra ZebraHeight ZebraHeight add def
  /yiter double-zebra LineHeight mul neg def
  /xiter PrintWidth InterColumn add def
  NumberOfColumns {LinesPerColumn doColumnZebra xiter 0 rmoveto}repeat
  grestore
} def

% stack:  lines-per-column |- --
/doColumnZebra {
  gsave
  dup double-zebra idiv {ZebraHeight doZebra 0 yiter rmoveto}repeat
  double-zebra mod
  dup 0 le {pop}{dup ZebraHeight gt {pop ZebraHeight}if doZebra}ifelse
  grestore
} def

% stack:  zebra-height (in lines) |- --
/doZebra {
  /zh exch 0.05 sub LineHeight mul def
  gsave
  0 LineHeight 0.65 mul rmoveto
  PrintWidth 0 rlineto
  0 zh neg rlineto
  PrintWidth neg 0 rlineto
  0 zh rlineto
  fill
  grestore
} def

% tx ty rotation xscale yscale xpos ypos BeginBackImage
/BeginBackImage {
  /-save-image- save def
  /showpage {}def
  translate
  scale
  rotate
  translate
} def

/EndBackImage {
  -save-image- restore
} def

% string fontsize fontname rotation gray xpos ypos ShowBackText
/ShowBackText {
  gsave
  translate
  setgray
  rotate
  findfont exch dup /-offset- exch -0.25 mul def scalefont setfont
  0 -offset- moveto
  /-saveLineThickness- LineThickness def
  /LineThickness 1 def
  false doOutline
  /LineThickness -saveLineThickness- def
  grestore
} def

/BeginDoc {
  % ---- save the state of the document (useful for ghostscript!)
  /docState save def
  % ---- [jack] Kludge: my ghostscript window is 21x27.7 instead of 21x29.7
  /JackGhostscript where {
    pop 1 27.7 29.7 div scale
  } if
  LandscapeMode {
    % ---- translate to bottom-right corner of Portrait page
    LandscapePageHeight 0 translate
    90 rotate
    } if
  /ColumnWidth PrintWidth InterColumn add def
  % ---- translate to lower left corner of TEXT
  LeftMargin BottomMargin translate
  % ---- define where  printing will start
  /f0 F					% this installs Ascent
  /PrintStartY PrintHeight Ascent sub def
  /ColumnIndex 1 def
} def

/EndDoc {
  % ---- on last page but not last column, spit out the page
  ColumnIndex 1 eq not { showpage } if
  % ---- restore the state of the document (useful for ghostscript!)
  docState restore
} def

/BeginDSCPage {
  % ---- when 1st column, save the state of the page
  ColumnIndex 1 eq { /pageState save def } if
  % ---- save the state of the column
  /columnState save def
} def

/PrintHeaderWidth PrintOnlyOneHeader{PrintPageWidth}{PrintWidth}ifelse def

/BeginPage {
  % ---- when 1st column, print all background effects
  ColumnIndex 1 eq {
  0 PrintStartY moveto			% move to where printing will start
  Zebra {printZebra}if
  printGlobalBackground
  printLocalBackground
  } if
  PrintHeader {
    PrintOnlyOneHeader{ColumnIndex 1 eq}{true}ifelse {
      PrintHeaderFrame {HeaderFrame}if
      HeaderText
    } if
  } if
  0 PrintStartY moveto			% move to where printing will start
  PLN
} def

/EndPage {
  bg { eolbg } if
} def

/EndDSCPage {
  ColumnIndex NumberOfColumns eq {
    % ---- on last column, spit out the page
    showpage
    % ---- restore the state of the page
    pageState restore
    /ColumnIndex 1 def
  } { % else
    % ---- restore the state of the current column
    columnState restore
    % ---- and translate to the next column
    ColumnWidth 0 translate
    /ColumnIndex ColumnIndex 1 add def
  } ifelse
} def

/SetHeaderLines {			% nb-lines --
  /HeaderLines exch def
  % ---- bottom up
  HeaderPad
  HeaderLines 1 sub HeaderLineHeight mul add
  HeaderTitleLineHeight add
  HeaderPad add
  /HeaderHeight exch def
} def

% |---------|
% |  tm     |
% |---------|
% |  header |
% |-+-------| <-- (x y)
% |  ho     |
% |---------|
% |  text   |
% |-+-------| <-- (0 0)
% |  bm     |
% |---------|

/HeaderFrameStart {			% -- x y
  0  PrintHeight HeaderOffset add
} def

/HeaderFramePath {
  PrintHeaderWidth	0			rlineto
  0			HeaderHeight		rlineto
  PrintHeaderWidth neg	0			rlineto
  0			HeaderHeight neg	rlineto
} def

/HeaderFrame {
  gsave
    0.4 setlinewidth
    % ---- fill a black rectangle (the shadow of the next one)
    HeaderFrameStart moveto
    1 -1 rmoveto
    HeaderFramePath
    0 setgray fill
    % ---- do the next rectangle ...
    HeaderFrameStart moveto
    HeaderFramePath
    gsave 0.9 setgray fill grestore	% filled with grey
    gsave 0 setgray stroke grestore	% drawn  with black
  grestore
} def

/HeaderStart {
  HeaderFrameStart
  exch HeaderPad add exch	% horizontal pad
  % ---- bottom up
  HeaderPad add			% vertical   pad
  HeaderDescent sub
  HeaderLineHeight HeaderLines 1 sub mul add
} def

/strcat {
  dup length 3 -1 roll dup length dup 4 -1 roll add string dup
  0 5 -1 roll putinterval
  dup 4 2 roll exch putinterval
} def

/pagenumberstring {
  PageNumber 32 string cvs
  ShowNofN {
    (/) strcat
    PageCount 32 string cvs strcat
  } if
} def

/HeaderText {
  HeaderStart moveto

  HeaderLinesRight HeaderLinesLeft	% -- rightLines leftLines

  % ---- hack: `PN 1 and'  ==  `PN 2 modulo'

  % ---- if duplex and even page number, then exchange left and right
  Duplex PageNumber 1 and 0 eq and { exch } if

  { % ---- process the left lines
    aload pop
    exch F
    gsave
      dup xcheck { exec } if
      show
    grestore
    0 HeaderLineHeight neg rmoveto
  } forall

  HeaderStart moveto

  { % ---- process the right lines
    aload pop
    exch F
    gsave
      dup xcheck { exec } if
      dup stringwidth pop
      PrintHeaderWidth exch sub HeaderPad 2 mul sub 0 rmoveto
      show
    grestore
    0 HeaderLineHeight neg rmoveto
  } forall
} def

/ReportFontInfo {
  2 copy
  /t0 3 1 roll DefFont
  /t0 F
  /lh FontHeight def
  /sw ( ) stringwidth pop def
  /aw (01234567890abcdefghijklmnopqrstuvwxyz) dup length exch
  stringwidth pop exch div def
  /t1 12 /Helvetica-Oblique DefFont
  /t1 F
  gsave
    (For ) show
    128 string cvs show
    ( ) show
    32 string cvs show
    ( point, the line height is ) show
    lh 32 string cvs show
    (, the space width is ) show
    sw 32 string cvs show
    (,) show
  grestore
  0 FontHeight neg rmoveto
  gsave
    (and a crude estimate of average character width is ) show
    aw 32 string cvs show
    (.) show
  grestore
  0 FontHeight neg rmoveto
} def

/cm { % cm to point
  72 mul 2.54 div
} def

/ReportAllFontInfo {
  FontDirectory
  { % key = font name  value = font dictionary
    pop 10 exch ReportFontInfo
  } forall
} def

% 3 cm 20 cm moveto  10 /Courier ReportFontInfo  showpage
% 3 cm 20 cm moveto  ReportAllFontInfo           showpage

")

(defvar ps-print-prologue-iso-8859-2
  (concat ps-print-prologue-iso-8859-2-composite
	  ps-print-prologue-iso-8859-2-fonts))

(defun ps-begin-file ()

  ;; ISO 8859-2 hack. If you know how to check it better, rewrite
  ;; it. And let me know.

  (if (memq 'latin-iso8859-2
	    (find-charset-string (buffer-substring (point-min) (point-max))))
      (progn
	(setq ps-print-national-prologue
	      ps-print-prologue-iso-8859-2)
	(setq ps-font-coding-extension "-Ogonki")
	;; Maybe -Ogonki as well?
	(setq ps-header-font-coding-extension ""))
    
    (setq ps-print-national-prologue ps-print-prologue-iso-8859-1)
    (setq ps-font-coding-extension "")
    (setq ps-header-font-coding-extension ""))

  (ps-get-page-dimensions)
  (setq ps-page-postscript 0
	ps-background-text-count 0
	ps-background-image-count 0
	ps-background-pages nil
	ps-background-all-pages nil)

  (ps-output ps-adobe-tag
	     "%%Title: " (buffer-name)	; Take job name from name of
					; first buffer printed
	     "\n%%Creator: " (user-full-name)
	     " (using cz/ps-print v" ps-print-version
	     ")\n%%CreationDate: "
	     (time-stamp-hh:mm:ss) " " (time-stamp-mon-dd-yyyy)
	     "\n%%Orientation: "
	     (if ps-landscape-mode "Landscape" "Portrait")
	     "\n%% DocumentFonts: Times-Roman Times-Italic "
	     (mapconcat 'identity
			(ps-remove-duplicates
			 (append (ps-fonts 'ps-font-for-text)
				 (list (ps-font 'ps-font-for-header 'normal)
				       (ps-font 'ps-font-for-header 'bold))))
			" ")
	     "\n%%Pages: (atend)\n"
	     "%%EndComments\n\n")

  (ps-output-boolean "LandscapeMode"             ps-landscape-mode)
  (ps-output (format "/NumberOfColumns %d def\n" ps-number-of-columns)

	     (format "/LandscapePageHeight %s def\n" ps-landscape-page-height)
	     (format "/PrintPageWidth      %s def\n"
		     (- (* (+ ps-print-width ps-inter-column)
			   ps-number-of-columns)
			ps-inter-column))
	     (format "/PrintWidth   %s def\n" ps-print-width)
	     (format "/PrintHeight  %s def\n" ps-print-height)

	     (format "/LeftMargin   %s def\n" ps-left-margin)
	     (format "/RightMargin  %s def\n" ps-right-margin) ; not used
	     (format "/InterColumn  %s def\n" ps-inter-column)

	     (format "/BottomMargin %s def\n" ps-bottom-margin)
	     (format "/TopMargin    %s def\n" ps-top-margin) ; not used
	     (format "/HeaderOffset %s def\n" ps-header-offset)
	     (format "/HeaderPad    %s def\n" ps-header-pad))

  (ps-output-boolean "PrintHeader"        ps-print-header)
  (ps-output-boolean "PrintOnlyOneHeader" ps-print-only-one-header)
  (ps-output-boolean "PrintHeaderFrame"   ps-print-header-frame)
  (ps-output-boolean "ShowNofN"           ps-show-n-of-n)
  (ps-output-boolean "Duplex"             ps-spool-duplex)

  (let ((line-height (ps-line-height 'ps-font-for-text)))
    (ps-output (format "/LineHeight   %s def\n" line-height)
	       (format "/LinesPerColumn %d def\n"
		       (round (/ (+ ps-print-height
				    (* line-height 0.45))
				 line-height)))))

  (ps-output-boolean "Zebra" ps-zebra-stripes)
  (ps-output-boolean "PrintLineNumber" ps-line-number)
  (ps-output (format "/ZebraHeight %d def\n" ps-zebra-stripe-height))

  (ps-background-text)
  (ps-background-image)
  (setq ps-background-all-pages (nreverse ps-background-all-pages)
	ps-background-pages (nreverse ps-background-pages))

  (ps-output ps-print-national-prologue)
  (ps-output ps-print-prologue)

  (ps-output "/printGlobalBackground {\n")
  (ps-output-list ps-background-all-pages)
  (ps-output "} def\n/printLocalBackground {\n} def\n")

  ;; Header fonts
  ;; hacked for ISO-8859-2
  (ps-output (format "/h0 %s /%s%s DefFont\n" ; /h0 14 /Helvetica-Bold DefFont
		     ps-header-title-font-size
		     (ps-font 'ps-font-for-header 'bold)
		     ps-header-font-coding-extension)
	     (format "/h1 %s /%s%s DefFont\n" ; /h1 12 /Helvetica DefFont
		     ps-header-font-size
		     (ps-font 'ps-font-for-header 'normal)
		     ps-header-font-coding-extension))

  (ps-output ps-print-prologue-2)

  ;; Text fonts
  (let ((font (ps-font-alist 'ps-font-for-text))
	(i 0))
    (while font
      (ps-output (format "/f%d %s /%s%s DefFont\n"
			 i
			 ps-font-size
			 (ps-font 'ps-font-for-text (car (car font)))
			 ps-font-coding-extension))
      (setq font (cdr font)
	    i (1+ i))))

  (ps-output "\nBeginDoc\n\n"
	     "%%EndPrologue\n"))

(provide 'cz-print)

;;; cz-print.el ends here
