;;; czech-calendar.el -- Czech calendar and holidays

;; Copyright (C) 1997, 1998 Milan Zamazal

;; Authors:    David ,B)(Bauer <xsauer@hwlab.felk.cvut.cz>,
;;             Milan Zamazal <pdm@fi.muni.cz>
;; Maintainer: Milan Zamazal <pdm@fi.muni.cz>
;; Version:    4.0
;; Keywords:   i18n, Czech, calendar, holidays

;; COPYRIGHT NOTICE
;;
;; This program is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by the Free
;; Software Foundation, version 2 of the License.
;;
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
;; for more details.
;;
;; You can find the GNU General Public License at
;; http://www.gnu.org/copyleft/gpl.html
;; or you can write to the Free Software Foundation, Inc., 675 Mass Ave.,
;; Cambridge, MA 02139, USA.

;;; Commentary:

;; This file defines and redefines various calendar things according to Czech
;; and Moravian national habits.

;;; History:

;; So long, so very long...

;;; Code:

;; Basic calendar settings according to Czech habits
(setq european-calendar-style t
      calendar-week-start-day 1
      calendar-day-name-array
      ["ned,Bl(Ble" "pond,Bl(Bl,Bm(B" ",Bz(Bter,B}(B" "st,Bx(Beda" ",Bh(Btvrtek" "p,Ba(Btek" "sobota"]
      calendar-month-name-array
      ["leden" ",Bz(Bnor" "b,Bx(Bezen" "duben" "kv,Bl(Bten" ",Bh(Berven"
       ",Bh(Bervenec" "srpen" "z,Baxm(B" ",Bxm(Bjen" "listopad" "prosinec"]
      display-time-24hr-format t
      cal-tex-24 t
      cal-tex-options "czech"
      calendar-date-display-form '(day ". " month ". " year)
      calendar-time-display-form '(24-hours ":" minutes
					    (if time-zone " (")
					    time-zone
					    (if time-zone ")")))

;; Do not allow short month names
(defun czech-calendar-hack ()
  (defun calendar-month-name (month &optional width)
    "The name of MONTH.
Redefinition of the original function because of some difficulties with Czech.
WIDTH is ignored because of this reason."
    (aref calendar-month-name-array (1- month))))
(if (featurep 'calendar)
    (czech-calendar-hack))
(add-hook 'calendar-load-hook 'czech-calendar-hack)

;; Czech holidays
(setq local-holidays
      '((holiday-fixed
	 1 1    "Nov,B}(B rok")
	(holiday-fixed
	 2 14   "Sv,Ba(Btek sv. Valent,B}(Bna")
	(holiday-fixed
	 4 1    "Apr,Bm(Bl!")
	(holiday-fixed
	 5 1    "Sv,Ba(Btek pr,Ba(Bce")
	(holiday-float
	 5 0 2  "Den matek")
	(holiday-fixed
	 5 5    "Pra,B>(Bsk,Bi(B povst,Ba(Bn,Bm(B (1945)")
	(holiday-fixed
	 5 8    "Den osvobozen,Bm(B od fa,B9(Bismu (1945)")
	(holiday-fixed
	 7 5    "Den slovansk,B}(Bch v,Bl(Brozv,Bl(Bst,By(B Cyrila a Metod,Bl(Bje")
	(holiday-fixed
	 7 6    "Mistr Jan Hus (1415)")
	(holiday-fixed
	 10 28  "Den vzniku samostatn,Bi(Bho ,Bh(Beskoslovensk,Bi(Bho st,Ba(Btu (1918)")
	(holiday-fixed
	 11 2   "Pam,Ba(Btka zesnul,B}(Bch")
	(holiday-fixed
	 11 17  "Den boje student,By(B za svobodu a demokracii")
	(holiday-fixed
	 12 24  ",B)(Bt,Bl(Bdr,B}(B den")
	(holiday-fixed
	 12 26  "2. sv,Ba(Btek v,Ba(Bno,Bh(Bn,Bm(B")
	(holiday-fixed
	 12 31  "Silvestr")))

;; Translate daylight savings time
(setq solar-holidays
  '((solar-equinoxes-solstices)
    (funcall
     'holiday-sexp
     calendar-daylight-savings-starts
     '(format "Za,Bhm(Bn,Ba(B letn,Bm(B ,Bh(Bas"))
    (funcall
     'holiday-sexp
     calendar-daylight-savings-ends
     '(format "Kon,Bhm(B letn,Bm(B ,Bh(Bas"))))

;; Translate solar seasons
(setq solar-n-hemi-seasons
  '("Jarn,Bm(B rovnodennost" "Letn,Bm(B slunovrat" 
    "Podzimn,Bm(B rovnodennost" "Zimn,Bm(B slunovrat"))

;; Translate Christian holidays
(setq christian-holidays
  '((if all-christian-calendar-holidays
        (holiday-fixed 1 6 "T,Bx(Bi kr,Ba(Blov,Bi(B"))
    (cz-holiday-easter-etc)
    (if all-christian-calendar-holidays
        (holiday-greek-orthodox-easter))
    (if all-christian-calendar-holidays
        (holiday-fixed 8 15 "Nanebvzet,Bm(B Panny Marie"))
    (if all-christian-calendar-holidays
        (holiday-advent))
    (holiday-fixed 12 25 "1. sv,Ba(Btek v,Ba(Bno,Bh(Bn,Bm(B")
    (if all-christian-calendar-holidays
        (holiday-julian 12 25 "Pravoslavn,Bi(B V,Ba(Bnoce"))))

;; Another replacing case.  Cut, paste & edit from `holidays.el' again.
;; Here we moreover slightly modify produced list, because in Czech Republic
;; there is another set of mandatory Easter holidays.
(defun cz-holiday-easter-etc ()
  "List of dates related to Easter, as visible in calendar window."
  (if (and (> displayed-month 5) (not all-christian-calendar-holidays))
      nil;; Ash Wednesday, Good Friday, and Easter are not visible.
    (let* ((century (1+ (/ displayed-year 100)))
	   (shifted-epact;; Age of moon for April 5...
	    (% (+ 14 (* 11 (% displayed-year 19));;     ...by Nicaean rule
		  (-;; ...corrected for the Gregorian century rule
		   (/ (* 3 century) 4))
		  (/;; ...corrected for Metonic cycle inaccuracy.
		   (+ 5 (* 8 century)) 25)
		  (* 30 century));;              Keeps value positive.
	       30))
	   (adjusted-epact;;  Adjust for 29.5 day month.
	    (if (or (= shifted-epact 0)
		    (and (= shifted-epact 1) (< 10 (% displayed-year 19))))
		(1+ shifted-epact)
	      shifted-epact))
	   (paschal-moon;; Day after the full moon on or after March 21.
	    (- (calendar-absolute-from-gregorian
		(list 4 19 displayed-year))
	       adjusted-epact))
	   (abs-easter (calendar-dayname-on-or-before
			0 (+ paschal-moon 7)))
	   (mandatory
	    (list
	     (list (calendar-gregorian-from-absolute abs-easter)
		   "Velikono,Bh(Bn,Bm(B ned,Bl(Ble")
	     (list (calendar-gregorian-from-absolute (1+ abs-easter))
		   "Velikono,Bh(Bn,Bm(B pond,Bl(Bl,Bm(B")))
	   (optional
	    (list
	     (list (calendar-gregorian-from-absolute (- abs-easter 49))
		   "Masopustn,Bm(B ned,Bl(Ble")
	     (list (calendar-gregorian-from-absolute (- abs-easter 48))
		   "Masopustn,Bm(B pond,Bl(Bl,Bm(B")
	     (list (calendar-gregorian-from-absolute (- abs-easter 47))
		   "Masopustn,Bm(B ,Bz(Bter,B}(B")
	     (list (calendar-gregorian-from-absolute (- abs-easter 46))
		   "Popele,Bh(Bn,Bm(B st,Bx(Beda")
	     (list (calendar-gregorian-from-absolute (- abs-easter 14))
		   "Smrtn,Ba(B ned,Bl(Ble")
	     (list (calendar-gregorian-from-absolute (- abs-easter 7))
		   "Kv,Bl(Btn,Ba(B ned,Bl(Ble")
	     (list (calendar-gregorian-from-absolute (- abs-easter 3))
		   "Zelen,B}(B ,Bh(Btvrtek")
	     (list (calendar-gregorian-from-absolute (- abs-easter 2))
		   "Velk,B}(B p,Ba(Btek")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 39))
		   "Nanebevstoupen,Bm(B P,Ba(Bn,Bl(B")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 49))
		   "Svatodu,B9(Bn,Bm(B ned,Bl(Ble")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 50))
		   "Svatodu,B9(Bn,Bm(B pond,Bl(Bl,Bm(B")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 56))
		   "Nejsv,Bl(Bt,Bl(Bj,B9m(B Trojice")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 60))
		   "T,Bl(Blo a Krev P,Ba(Bn,Bl(B")
	     (list (calendar-gregorian-from-absolute (+ abs-easter 68))
		   "Nejsv,Bl(Bt,Bl(Bj,B9m(B Srdce Je,B>m9(Bovo")))
	   (output-list
	    (filter-visible-calendar-holidays mandatory)))
      (if all-christian-calendar-holidays
	  (setq output-list
		(append 
		 (filter-visible-calendar-holidays optional)
		 output-list)))
      output-list)))


;;; *** Announce ***

(provide 'czech-calendar)


;;; czech-calendar.el ends here

